@@ -82,6 +82,7 @@ public class PreferenceManager implements PropertyManager {
     final public static String GENOMES_SEQUENCE_URL = "IGVMainFrame.genome.sequence.dir";
     final public static String JOIN_ADJACENT_SEGMENTS_KEY = "IGVMainFrame.join.adjacent.segments";
     final public static String SHOW_REGION_TOOL_KEY = "IGVMainFrame.show.region.tool";
+    final public static String SHOW_REGION_BARS = "SHOW_REGION_BARS";
     final public static String LAST_EXPORTED_REGION_DIRECTORY = "LAST_EXPORTED_REGION_DIRECTORY";
     final static public String LAST_TRACK_DIRECTORY = "LAST_TRACK_DIRECTORY";
     final static public String LAST_ATTRIBUTE_FILE_DIRECTORY = "LAST_ATTRIBUTE_FILE_DIRECTORY";
@@ -115,6 +116,10 @@ public class PreferenceManager implements PropertyManager {
     final public static String PROBE_MAPPING_KEY = "PROBE_MAPPING_KEY";
     final public static String SEARCH_ZOOM = "SEARCH_ZOOM";
     final public static String NORMALIZE_COVERAGE = "NORMALIZE_COVERAGE";
+    public static final String SHOW_EXPAND_ICON = "SHOW_EXPAND_ICON";
+
+    public static final String SHOW_SIZE_WARNING = "SHOW_SIZE_WARNING";
+    public static final String SHOW_GENOME_SERVER_WARNING = "SHOW_GENOME_SERVER_WARNING";
 
     final public static String USE_PROXY = "PROXY.USE";
     final public static String PROXY_HOST = "PROXY.HOST";
@@ -160,6 +165,7 @@ public class PreferenceManager implements PropertyManager {
     private Map<String, Object> objectCache = new Hashtable();
     private Map<TrackType, ContinuousColorScale> colorScaleCache = new Hashtable();
 
+
     public static PreferenceManager getInstance() {
 
         return instance;
@@ -233,6 +239,14 @@ public class PreferenceManager implements PropertyManager {
         return getBooleanPreference(PROBE_MAPPING_KEY, false);
     }
 
+    public boolean isShowRegionBars() {
+        return getBooleanPreference(SHOW_REGION_BARS, false);
+    }
+
+    public void setShowRegionBars(boolean show) {
+        put(SHOW_REGION_BARS, String.valueOf(show));
+    }
+
     public boolean isJoinAdjacentSegments() {
         return getBooleanPreference(JOIN_ADJACENT_SEGMENTS_KEY, false);
     }
@@ -813,7 +827,7 @@ public class PreferenceManager implements PropertyManager {
      * @return
      */
     public String getTrackAttributeName() {
-        return get(TRACK_ATTRIBUTE_NAME_KEY, "SAMPLE");
+        return get(TRACK_ATTRIBUTE_NAME_KEY, "Sample");
     }
 
     /**
@@ -1252,6 +1266,7 @@ public class PreferenceManager implements PropertyManager {
 
             prefs.setMaxVisibleRange(Float.parseFloat(get(SAMPreferences.MAX_VISIBLE_RANGE, "30")));
             prefs.setShowDuplicates(getBooleanPreference(SAMPreferences.SHOW_DUPLICATES, false));
+            prefs.setShowSoftClipped(getBooleanPreference(SAMPreferences.SHOW_SOFT_CLIPPED, false));
             prefs.setQualityThreshold(Integer.parseInt(get(SAMPreferences.QUALITY_THRESHOLD, "0")));
             prefs.setInsertSizeThreshold(Integer.parseInt(get(SAMPreferences.INSERT_SIZE_THRESHOLD, "10000")));
             prefs.setFlagUnmappedPair(getBooleanPreference(SAMPreferences.FLAG_UNMAPPED_PAIR, false));
@@ -1265,6 +1280,7 @@ public class PreferenceManager implements PropertyManager {
             prefs.setBaseQualityMin(getIntegerPreference(SAMPreferences.BASE_QUALITY_MIN, 5));
             prefs.setBaseQualityMax(getIntegerPreference(SAMPreferences.BASE_QUALITY_MAX, 20));
             prefs.setFilterAlignments(getBooleanPreference(SAMPreferences.FILTER_ALIGNMENTS, false));
+            prefs.setFilterFailedReads(getBooleanPreference(SAMPreferences.FILTER_FAILED_READS, true));
             prefs.setAlleleFreqThreshold(Float.parseFloat(get(SAMPreferences.ALLELE_THRESHOLD, "0.2f")));
             prefs.setFilterURL(get(SAMPreferences.FILTER_URL, null));
             prefs.setColorBy(get(SAMPreferences.COLOR_BY, null));
@@ -1295,6 +1311,7 @@ public class PreferenceManager implements PropertyManager {
         public static final String MAX_VISIBLE_RANGE = "SAM.MAX_VISIBLE_RANGE";
         public static final String SHOW_ZERO_QUALITY = "SAM.SHOW_VISIBLE_QUALITY";
         public static final String SHOW_DUPLICATES = "SAM.SHOW_DUPLICATES";
+        public static final String SHOW_SOFT_CLIPPED = "SAM.SHOW_SOFT_CLIPPED";
         public static final String FLAG_UNMAPPED_PAIR = "SAM.FLAG_UNMAPPED_PAIR";
         public static final String MAX_LEVELS = "SAM.MAX_LEVELS";
         public static final String MAX_READS = "SAM.MAX_READS";
@@ -1311,8 +1328,10 @@ public class PreferenceManager implements PropertyManager {
         public static final String FILTER_ALIGNMENTS = "SAM.FILTER_ALIGNMENTS";
         public static final String FILTER_URL = "SAM.FILTER_URL";
         public static final String COLOR_BY = "SAM.COLOR_BY";
+        public static final String FILTER_FAILED_READS = "SAM.FILTER_FAILED_READS";
 
         private boolean filterAlignments = false;
+        private boolean filterFailedReads = true;
         private String filterURL;
         private float maxVisibleRange;
         private int maxLevels;
@@ -1330,6 +1349,7 @@ public class PreferenceManager implements PropertyManager {
         private boolean shadeCenterFlag;
         private float alleleFreqThreshold = 0.2f;
         private String colorBy = "INSERT_SIZE";
+        private boolean showSoftClipped = false;
 
         /**
          * @return the maxVisibleRange
@@ -1535,5 +1555,22 @@ public class PreferenceManager implements PropertyManager {
         public void setColorBy(String colorBy) {
             this.colorBy = colorBy;
         }
+
+
+        public boolean isFilterFailedReads() {
+            return filterFailedReads;
+        }
+
+        public void setFilterFailedReads(boolean filterFailedReads) {
+            this.filterFailedReads = filterFailedReads;
+        }
+
+        public boolean isShowSoftClipped() {
+            return showSoftClipped;
+        }
+
+        public void setShowSoftClipped(boolean showSoftClipped) {
+            this.showSoftClipped = showSoftClipped;
+        }
     }
 }
