@@ -465,10 +465,6 @@ public class GCTDatasetParser {
         }
 
 
-        // and to loop through the list
-        if (log.isDebugEnabled()) {
-            log.debug("Searching probeToGene map");
-        }
         String[] loci = ProbeToGeneMap.getInstance().getGenesForProbe(probeId);
 
         if (loci != null) {
@@ -476,11 +472,6 @@ public class GCTDatasetParser {
                 Locus locus = getLocus(locusString);
                 //Feature gene = FeatureDB.getFeature(locusString);
 
-                if (log.isDebugEnabled()) {
-                    log.debug(locusString + " -> " + locus);
-                }
-
-
                 if (locus != null) {
                     addRow(probeId, locus, values);
                 }
@@ -613,9 +604,6 @@ public class GCTDatasetParser {
 
     Locus getLocus(String locusString) {
         Locus locus = new Locus(locusString);
-        if (locusString.equalsIgnoreCase("tp53")) {
-            System.out.println();
-        }
         if (locus.isValid()) {
             return locus;
         } else {
