@@ -264,7 +264,8 @@ public class IGVDatasetParser {
                     updateLongestFeature(longestFeatureMap, thisChr, length);
 
                     if (wgData.locations.size() > 0 && wgData.locations.get(wgData.locations.size() - 1) > location) {
-                        throw new ParserException("File is not sorted.", reader.getCurrentLineNumber());
+                        throw new ParserException("File is not sorted, .igv and .cn files must be sorted by start position." +
+                                " Use igvtools (File > Run igvtools..) to sort the file.", reader.getCurrentLineNumber());
                     }
 
 
