@@ -19,6 +19,7 @@
 package org.broad.igv.feature;
 
 import org.apache.log4j.Logger;
+import org.broad.igv.exceptions.DataLoadException;
 import org.broad.igv.exceptions.ParserException;
 import org.broad.igv.renderer.BasicFeatureRenderer;
 import org.broad.igv.renderer.GeneTrackRenderer;
@@ -143,6 +144,10 @@ public class GFFParser implements FeatureParser {
             reader = ParsingUtils.openAsciiReader(locator);
 
             List<Feature> features = loadFeatures(reader);
+            if (features.size() == 0) {
+                throw new DataLoadException("No features were found in this file with chromosomes mapped to the current genome", locator.getPath());
+            }
+
 
             FeatureTrack track = new FeatureTrack(locator, new FeatureCollectionSource(features));
             track.setName(locator.getTrackName());
@@ -377,11 +382,11 @@ public class GFFParser implements FeatureParser {
         for (Map.Entry<String, String> att : attributes.entrySet()) {
 
             //if (!ignoreAttributes.contains(att.getKey())) {
-                String attValue = att.getValue().replaceAll(";", "<br>");
-                buf.append(att.getKey());
-                buf.append(" = ");
-                buf.append(attValue);
-                buf.append("<br>");
+            String attValue = att.getValue().replaceAll(";", "<br>");
+            buf.append(att.getKey());
+            buf.append(" = ");
+            buf.append(attValue);
+            buf.append("<br>");
             //}
         }
         String description = buf.toString();
@@ -607,7 +612,6 @@ public class GFFParser implements FeatureParser {
 
             if ((parentId != null) && geneCache.containsKey(parentId)) {
                 BasicFeature gene = geneCache.get(parentId);
-                geneCache.remove(parentId);
                 if (transcript.getName() == null && gene.getName() != null) {
                     transcript.setName(gene.getName());
                 }
