@@ -288,7 +288,7 @@ public class GenomeImporter {
                 propertyFileWriter.println(Globals.GENOME_ARCHIVE_GENE_FILE_KEY + "=" + refFlatFile.getName());
             }
             if (relativeSequenceLocation != null) {
-                if (!relativeSequenceLocation.startsWith("http:")) {
+                if (!(relativeSequenceLocation.startsWith("http:") || relativeSequenceLocation.startsWith("https:"))) {
                     relativeSequenceLocation = relativeSequenceLocation.replace('\\', '/');
                 }
                 propertyFileWriter.println(Globals.GENOME_ARCHIVE_SEQUENCE_FILE_LOCATION_KEY + "=" + relativeSequenceLocation);
