@@ -32,6 +32,7 @@ import org.broad.igv.ui.UIConstants;
 
 import static org.broad.igv.ui.UIConstants.GENOME_CACHE_DIRECTORY;
 
+import org.broad.igv.ui.util.ConfirmDialog;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.ui.util.ProgressMonitor;
 import org.broad.igv.util.FileUtils;
@@ -102,7 +103,7 @@ public class GenomeManager {
      * @param id Genome id.
      * @return
      */
-    public Genome getGenome(String id)  {
+    public Genome getGenome(String id) {
 
         if (log.isDebugEnabled()) {
             log.debug("Enter getGenome: " + id);
@@ -123,7 +124,7 @@ public class GenomeManager {
         return genome;
     }
 
-    private Genome loadGenome(GenomeDescriptor genomeDescriptor)  {
+    private Genome loadGenome(GenomeDescriptor genomeDescriptor) {
         InputStream is = null;
         try {
 
@@ -305,6 +306,7 @@ public class GenomeManager {
                 }
 
                 if (genomeArchiveFileLocation.toLowerCase().startsWith("http:") ||
+                        genomeArchiveFileLocation.toLowerCase().startsWith("https:") ||
                         genomeArchiveFileLocation.toLowerCase().startsWith("file:")) {
 
                     URL genomeArchiveURL = new URL(genomeArchiveFileLocation);
@@ -477,7 +479,8 @@ public class GenomeManager {
 
                     String sequenceLocation = properties.getProperty(Globals.GENOME_ARCHIVE_SEQUENCE_FILE_LOCATION_KEY);
 
-                    if ((sequenceLocation != null) && !sequenceLocation.startsWith("http:")) {
+                    if ((sequenceLocation != null) && !(sequenceLocation.startsWith("http:") ||
+                            sequenceLocation.startsWith("https:"))) {
                         File tempZipFile = new File(zipFilePath);
                         File sequenceFolder = new File(tempZipFile.getParent(), sequenceLocation);
                         sequenceLocation = sequenceFolder.getCanonicalPath();
@@ -584,11 +587,25 @@ public class GenomeManager {
         LinkedHashSet<GenomeListItem> genomeItemList = new LinkedHashSet();
         BufferedReader dataReader = null;
         InputStream inputStream = null;
+        HttpURLConnection conn = null;
         try {
+            String genomeListURL = PreferenceManager.getInstance().getGenomeListURL();
+            URL serverGenomeArchiveList = new URL(genomeListURL);
 
-            URL serverGenomeArchiveList = new URL(PreferenceManager.getInstance().getGenomeListURL());
+            if (genomeListURL.startsWith("ftp:")) {
+                MessageUtils.showMessage("FTP protocol not supported for genome URL");
+
+            } else if (genomeListURL.startsWith("http:") || genomeListURL.startsWith("https:")) {
+                conn = IGVHttpUtils.openConnection(serverGenomeArchiveList);
+                conn.setReadTimeout(10000);
+                conn.setConnectTimeout(10000);
+                inputStream = IGVHttpUtils.openConnectionStream(serverGenomeArchiveList);
+                inputStream = IGVHttpUtils.openHttpStream(serverGenomeArchiveList, conn);
+            } else {
+                File file = new File(genomeListURL.startsWith("file:") ? serverGenomeArchiveList.getFile() : genomeListURL);
+                inputStream = new FileInputStream(file);
+            }
 
-            inputStream = IGVHttpUtils.openConnectionStream(serverGenomeArchiveList);
 
             dataReader = new BufferedReader(new InputStreamReader(inputStream));
 
@@ -638,7 +655,9 @@ public class GenomeManager {
         } catch (Exception e) {
             serverGenomeListUnreachable = true;
             log.error("Error fetching genome list: ", e);
-            MessageUtils.showMessage("Error fetching genome list: " + e.toString());
+            ConfirmDialog.optionallyShowInfoDialog("Warning: There was an error connecting to the genome server (" +
+                    e.toString() + ").    Only locally defined genomes will be available.",
+                    PreferenceManager.SHOW_GENOME_SERVER_WARNING);
         } finally {
             if (dataReader != null) {
                 dataReader.close();
