@@ -37,8 +37,7 @@ import java.util.Map;
  */
 public class AlignmentRenderer implements FeatureRenderer {
 
-    public static Map<Character, Color> nucleotideColors = new HashMap();
-
+    public static Map<Character, Color> nucleotideColors;
     // Static because all alignment tracks are in color space, or none are
     public static boolean colorSpace;
 
@@ -52,18 +51,6 @@ public class AlignmentRenderer implements FeatureRenderer {
     private static Color grey2 = new Color(165, 165, 165);
     public static Color grey1 = new Color(200, 200, 200);
 
-    static {
-        nucleotideColors.put('A', Color.GREEN);
-        nucleotideColors.put('a', Color.GREEN);
-        nucleotideColors.put('C', Color.BLUE);
-        nucleotideColors.put('c', Color.BLUE);
-        nucleotideColors.put('T', Color.RED);
-        nucleotideColors.put('t', Color.RED);
-        nucleotideColors.put('G', new Color(209, 113, 5));
-        nucleotideColors.put('g', new Color(209, 113, 5));
-        nucleotideColors.put('N', Color.gray.brighter());
-        nucleotideColors.put('n', Color.gray.brighter());
-    }
 
     static Font font = FontManager.getScalableFont(10);
     private ViewContext viewContext;
@@ -74,7 +61,22 @@ public class AlignmentRenderer implements FeatureRenderer {
 
     private static final Color negStrandColor = new Color(110, 145, 225);
     private static final Color posStrandColor = new Color(165, 35, 39);
+    PreferenceManager.SAMPreferences prefs;
 
+    synchronized static void initColorMap() {
+        nucleotideColors = new HashMap();
+        nucleotideColors.put('A', Color.GREEN);
+        nucleotideColors.put('a', Color.GREEN);
+        nucleotideColors.put('C', Color.BLUE);
+        nucleotideColors.put('c', Color.BLUE);
+        nucleotideColors.put('T', Color.RED);
+        nucleotideColors.put('t', Color.RED);
+        nucleotideColors.put('G', new Color(209, 113, 5));
+        nucleotideColors.put('g', new Color(209, 113, 5));
+        nucleotideColors.put('N', Color.gray.brighter());
+        nucleotideColors.put('n', Color.gray.brighter());
+
+    }
 
 
     /**
@@ -82,6 +84,10 @@ public class AlignmentRenderer implements FeatureRenderer {
      */
     public AlignmentRenderer() {
         this.viewContext = ViewContext.getInstance();
+        this.prefs = PreferenceManager.getInstance().getSAMPreferences();
+        if (nucleotideColors == null) {
+            initColorMap();
+        }
 
     }
 
@@ -396,6 +402,7 @@ public class AlignmentRenderer implements FeatureRenderer {
         String genome = context.getGenomeId();
 
         byte[] read = block.getBases();
+        boolean isSoftClipped = block.isSoftClipped();
 
         if ((read != null) && (read.length > 0)) {
 
@@ -412,7 +419,7 @@ public class AlignmentRenderer implements FeatureRenderer {
             // Get the base qualities, start/end,  and reference sequence
             int start = block.getStart();
             int end = start + read.length;
-            byte[] reference = SequenceManager.readSequence(genome, chr, start, end);
+            byte[] reference = isSoftClipped ? null : SequenceManager.readSequence(genome, chr, start, end);
 
 
             // Loop through base pair coordinates
@@ -423,21 +430,25 @@ public class AlignmentRenderer implements FeatureRenderer {
                 int idx = loc - start;
 
                 // Is this base posA mismatch?  Note '=' means indicates posA match by definition
-                // If we do not have posA valid reference we assume posA match
+                // If we do not have posA valid reference we assume posA match.  Soft clipped
+                // bases are considered mismatched by definition
                 boolean misMatch =
-                        read[idx] != '=' &&
+                        isSoftClipped ||
+                        (read[idx] != '=' &&
                                 reference != null &&
                                 idx < reference.length &&
                                 reference[idx] != 0 &&
-                                reference[idx] != read[idx];
+                                reference[idx] != read[idx]);
 
                 if (misMatch || showAllBases) {
                     char c = (char) read[loc - start];
+
+
                     Color color = nucleotideColors.get(c);
                     if (color == null) {
                         color = Color.black;
                     }
-                    PreferenceManager.SAMPreferences prefs = PreferenceManager.getInstance().getSAMPreferences();
+
                     if (shadeBases) {
                         byte qual = block.getQuality(loc - start);
                         color = getShadedColor(qual, color, prefs);
