@@ -37,8 +37,6 @@ import org.broad.igv.ui.util.FileChooserDialog;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.ColorUtilities;
-import org.broad.igv.util.LongRunningTask;
-import org.broad.igv.util.NamedRunnable;
 import org.broad.igv.util.ResourceLocator;
 
 import javax.swing.*;
@@ -279,7 +277,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         if (context.getScale() > minVisibleScale) {
 
             Graphics2D g = context.getGraphic2DForColor(Color.gray);
-            GraphicUtils.drawCenteredText("Zoom in to see alignments.", rect, g);
+            GraphicUtils.drawCenteredText("Zoom in to see alignments.", context.getVisibleRect(), g);
             return;
         }
 
@@ -288,11 +286,28 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
     private void renderFeatures(RenderContext context, Rectangle inputRect) {
         try {
+            log.debug("Render features");
+            final String genomeId = context.getGenomeId();
+            final String chr = context.getChr();
+            final int start = (int) context.getOrigin();
+            final int end = (int) context.getEndLocation() + 1;
+            List<AlignmentInterval.Row> tmp = dataManager.getAlignmentRows(genomeId, chr, start, end);
 
-            if (dataManager.getAlignmentRows() == null) {
+            if (tmp == null) {
                 return;
             }
 
+            // Check currently loaded interval.  If out of range null it.  This probably isn't the best place
+            // to check this.
+            //AlignmentInterval interval = dataManager.getLoadedInterval();
+            //if (interval != null &&
+            //        (!interval.chr.equals(context.getChr()) ||
+            //        interval.getStart() > context.getEndLocation() ||
+            //        interval.getEnd() < context.getOrigin())) {
+            //    dataManager.setLoadedInterval(null);
+            // return;
+            //}
+
             PreferenceManager.SAMPreferences prefs = PreferenceManager.getInstance().getSAMPreferences();
             int maxLevels = prefs.getMaxLevels();
 
@@ -310,8 +325,9 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
             int levelNumber = 0;
             // levelList is copied to prevent concurrent modification exception
-            List<AlignmentDataManager.Row> tmp = new ArrayList(dataManager.getAlignmentRows());
-            for (AlignmentDataManager.Row row : tmp) {
+            //List<AlignmentDataManager.Row> tmp = new ArrayList(dataManager.getAlignmentRows());
+
+            for (AlignmentInterval.Row row : tmp) {
 
                 if ((visibleRect != null && y > visibleRect.getMaxY()) ||
                         levelNumber > maxLevels) {
@@ -341,33 +357,9 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
     }
 
     public void reloadData() {
-        dataManager.setLoadedInterval(null);
-        preloadData();
-
+        dataManager.reload();
     }
 
-    public void preloadData() {
-        ViewContext vc = ViewContext.getInstance();
-        preloadData(vc.getChrName(), (int) vc.getOrigin(), (int) vc.getEnd(), vc.getZoom());
-    }
-
-    public boolean isLoading = false;
-
-    @Override
-    public synchronized void preloadData(final String chr, final int start, final int end, final int zoom) {
-
-        NamedRunnable runnable = new NamedRunnable() {
-            public String getName() {
-                return "preloadData";  
-            }
-
-            public void run() {
-                dataManager.preloadData(chr, start, end, zoom);
-            }
-        };
-        LongRunningTask.submit(runnable);
-
-    }
 
     /**
      * Sort alignment rows such that alignments that intersect from the
@@ -419,6 +411,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
                 selectedReadNames.clear();
                 selectedReadNames.put(alignment.getReadName(), Color.black);
                 ViewContext.getInstance().centerOnLocation(chr, start);
+                ViewContext.getInstance().recordHistory();
             }
         }
 
@@ -473,7 +466,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
             return null;
         }
 
-        AlignmentDataManager.Row row = dataManager.getAlignmentRows().get(levelNumber);
+        AlignmentInterval.Row row = dataManager.getAlignmentRows().get(levelNumber);
         List<Alignment> features = row.alignments;
 
         // give posA 2 pixel window, otherwise very narrow features will be missed.
@@ -509,12 +502,10 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
             if (f.getStart() > right) {
                 rightBounds = idx;
-                idx =
-                        (leftBounds + idx) / 2;
+                idx = (leftBounds + idx) / 2;
             } else {
                 leftBounds = idx;
-                idx =
-                        (rightBounds + idx) / 2;
+                idx = (rightBounds + idx) / 2;
 
             }
 
@@ -589,8 +580,10 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         addCopyToClipboardItem(popupMenu, evt);
         popupMenu.addSeparator();
 
-        JLabel trackSettingsHeading = new JLabel("  Track Settings",
-                JLabel.LEFT);
+        addSelecteByNameItem(popupMenu);
+        popupMenu.addSeparator();
+
+        JLabel trackSettingsHeading = new JLabel("  Track Settings", JLabel.LEFT);
         trackSettingsHeading.setFont(newFont);
 
         popupMenu.add(trackSettingsHeading);
@@ -610,6 +603,23 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         return popupMenu;
     }
 
+    public void addSelecteByNameItem(JPopupMenu menu) {
+        // Change track height by attribute
+        JMenuItem item = new JMenuItem("Select by name...");
+        item.addActionListener(new ActionListener() {
+
+            public void actionPerformed(ActionEvent e) {
+                String val = MessageUtils.showInputDialog("Enter read name: ");
+                if (val != null && val.trim().length() > 0) {
+                    selectedReadNames.put(val, ColorUtilities.randomColor(selectedReadNames.size() + 1));
+                    refresh();
+                }
+            }
+        });
+
+        menu.add(item);
+    }
+
     public void addSortMenuItem(JPopupMenu menu) {
         // Change track height by attribute
         JMenu item = new JMenu("Sort alignments");
@@ -619,7 +629,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
             public void actionPerformed(ActionEvent e) {
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.START);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -629,7 +639,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
             public void actionPerformed(ActionEvent e) {
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.STRAND);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -640,7 +650,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
             public void actionPerformed(ActionEvent e) {
 
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.NUCELOTIDE);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -651,7 +661,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
             public void actionPerformed(ActionEvent e) {
 
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.QUALITY);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -662,7 +672,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
             public void actionPerformed(ActionEvent e) {
 
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.SAMPLE);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -673,7 +683,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
             public void actionPerformed(ActionEvent e) {
 
                 IGVMainFrame.getInstance().getTrackManager().sortAlignmentTracks(SortOption.READ_GROUP);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
 
             }
         });
@@ -710,7 +720,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         m1.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 setColorOption(ColorOption.INSERT_SIZE);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
             }
         });
 
@@ -719,7 +729,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         m1a.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 setColorOption(ColorOption.PAIR_ORIENTATION);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
             }
         });
 
@@ -728,7 +738,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         m2.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 setColorOption(ColorOption.READ_STRAND);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
             }
         });
 
@@ -737,7 +747,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         m3.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 setColorOption(ColorOption.FRAGMENT_STRAND);
-                IGVMainFrame.getInstance().repaintDataPanels();
+                refresh();
             }
         });
 
@@ -763,7 +773,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
                     public void run() {
                         IGVMainFrame.getInstance().getTrackManager().packAlignmentTracks();
-                        IGVMainFrame.getInstance().repaintDataPanels();
+                        refresh();
                     }
                 });
             }
@@ -816,7 +826,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
                     public void run() {
                         AlignmentTrack.this.selectedReadNames.clear();
-                        IGVMainFrame.getInstance().repaintDataPanels();
+                        refresh();
                     }
                 });
             }
@@ -836,7 +846,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
                     public void run() {
                         renderOptions.showAllBases = item.isSelected();
-                        IGVMainFrame.getInstance().repaintDataPanels();
+                        refresh();
                     }
                 });
             }
@@ -851,31 +861,30 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
         item.addActionListener(new ActionListener() {
 
             public void actionPerformed(ActionEvent e) {
-                UIUtilities.invokeOnEventThread(new Runnable() {
-
-                    public void run() {
-                        int threshold = renderOptions.insertSizeThreshold;
-                        String val = JOptionPane.showInputDialog("Enter insert size threshold: ", String.valueOf(threshold));
-                        try {
-                            int newThreshold = Integer.parseInt(val);
-                            if (newThreshold != threshold) {
-                                renderOptions.insertSizeThreshold = newThreshold;
-                                IGVMainFrame.getInstance().repaintDataPanels();
-                            }
-                        }
-                        catch (NumberFormatException e) {
-                            MessageUtils.showMessage("Insert size must be an integer value: " + val);
-                        }
-
-
+                int threshold = renderOptions.insertSizeThreshold;
+                String val = MessageUtils.showInputDialog("insert size threshold", String.valueOf(threshold));
+                try {
+                    int newThreshold = Integer.parseInt(val);
+                    if (newThreshold != threshold) {
+                        renderOptions.insertSizeThreshold = newThreshold;
+                        refresh();
                     }
-                });
+                }
+                catch (NumberFormatException ex) {
+                    MessageUtils.showMessage("Insert size must be an integer value: " + val);
+                }
+
             }
         });
 
+
         menu.add(item);
     }
 
+    private void refresh() {
+        IGVMainFrame.getInstance().repaintDataPanels();
+    }
+
     public void addShadeBaseMenuItem(JPopupMenu menu) {
         // Change track height by attribute
         final JMenuItem item = new JCheckBoxMenuItem("Shade base by quality");
@@ -887,7 +896,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
 
                     public void run() {
                         renderOptions.shadeBases = item.isSelected();
-                        IGVMainFrame.getInstance().repaintDataPanels();
+                        refresh();
                     }
                 });
             }
@@ -908,7 +917,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
                     public void run() {
 
                         renderOptions.shadeCenters = item.isSelected();
-                        IGVMainFrame.getInstance().repaintDataPanels();
+                        refresh();
                     }
                 });
             }
@@ -930,7 +939,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
                     public void run() {
                         if (getCoverageTrack() != null) {
                             getCoverageTrack().setVisible(item.isSelected());
-                            IGVMainFrame.getInstance().repaintDataPanels();
+                            refresh();
                             IGVMainFrame.getInstance().repaintNamePanels();
                         }
                     }
@@ -962,7 +971,7 @@ public class AlignmentTrack extends AbstractTrack implements DragListener {
                                 TDFReader reader = TDFReader.getReader(file.getAbsolutePath());
                                 TDFDataSource ds = new TDFDataSource(reader, 0, getName() + " coverage");
                                 getCoverageTrack().setDataSource(ds);
-                                IGVMainFrame.getInstance().repaintDataPanels();
+                                refresh();
                             } else {
                                 MessageUtils.showMessage("Coverage data must be in .tdf format");
                             }
