@@ -145,10 +145,12 @@ public class CoverageTrack extends AbstractTrack {
         if (dataManager != null) {
             interval = dataManager.getLoadedInterval();
         }
-        if (interval != null) {
+
+
+        if (interval != null && interval.overlaps(context.getGenomeId(), context.getChr(), (int) context.getOrigin(),
+                (int) context.getEndLocation())) {
             intervalRenderer.paint(context, rect, interval);
         }
-
         // Use precomputed data source, if any
         else if (dataSource != null) {
             String chr = context.getChr();
@@ -162,6 +164,9 @@ public class CoverageTrack extends AbstractTrack {
 
         }
 
+
+
+
         // Draw border
         context.getGraphic2DForColor(Color.gray).drawLine(
                 rect.x, rect.y + rect.height,
