@@ -23,6 +23,7 @@ import net.sf.samtools.SAMFileHeader;
 import net.sf.samtools.SAMReadGroupRecord;
 import net.sf.samtools.SAMRecord;
 import org.apache.log4j.Logger;
+import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.Genome;
 import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.Strand;
@@ -52,6 +53,8 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     public static final char HARD_CLIP = 'H';
     public static final char PADDING = 'P';
     public static final char ZERO_GAP = 'O';
+    private int start;  // <= Might differ from alignment start if soft clipping is considered
+    private int end;    // ditto
     private int alignmentStart;
     private int alignmentEnd;
     boolean negativeStrand;
@@ -90,7 +93,9 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         // SAMRecord is 1 based inclusive.  IGV is 0 based exclusive.
         this.alignmentStart = record.getAlignmentStart() - 1;
+        this.start = this.alignmentStart;   // might be modified later for soft clipping
         this.alignmentEnd = Math.max(alignmentStart, record.getAlignmentEnd());
+        this.end = alignmentEnd;   // might be modified later for soft clipping
         this.negativeStrand = record.getReadNegativeStrandFlag();
         this.cigarString = record.getCigarString();
         this.setMappingQuality(record.getMappingQuality());
@@ -183,6 +188,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         this.chr = alignment.chr;
         this.alignmentStart = alignment.alignmentStart;
         this.alignmentEnd = alignment.alignmentEnd;
+        this.end = alignment.end;
         this.negativeStrand = alignment.negativeStrand;
         this.mate = alignment.mate;
         this.alignmentBlocks = alignment.alignmentBlocks;
@@ -216,6 +222,9 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
     void createAlignmentBlocks(String cigarString, byte[] readBases, byte[] readBaseQualities) {
 
+        boolean showSoftClipped = PreferenceManager.getInstance().getSAMPreferences().isShowSoftClipped();
+
+
         int nInsertions = 0;
         int nBlocks = 0;
 
@@ -231,7 +240,7 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         boolean firstOperator = true;
         int softClippedBaseCount = 0;
         int nGaps = 0;
-        char lastOperator = 0;
+        char prevOp = 0;
         for (int i = 0; i < cigarString.length(); i++) {
             char next = cigarString.charAt(i);
             if (Character.isDigit(next)) {
@@ -239,23 +248,26 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
             } else {
                 int nBases = Integer.parseInt(buffer.toString());
                 char op = next;
-                if (op == MATCH || op == PERFECT_MATCH || op == MISMATCH) {
-                    if (lastOperator == MATCH || lastOperator == PERFECT_MATCH || lastOperator == MISMATCH) {
+                if (operatorIsMatch(showSoftClipped, op)) {
+                    if (operatorIsMatch(showSoftClipped, prevOp)) {
                         nGaps++;   // Consecutive Ms
                     }
                     nBlocks++;
-                } else if (op == SOFT_CLIP && firstOperator) {
-                    softClippedBaseCount += nBases;
+
                 } else if (op == DELETION || op == SKIPPED_REGION) {
                     nGaps++;
                 } else if (op == INSERTION) {
                     nInsertions++;
                     nGaps++; // "virtual" gap, account for artificial block split @ insertion
                 }
+                if (firstOperator && op == SOFT_CLIP) {
+                    softClippedBaseCount += nBases;
+                }
+
                 operators.add(new CigarOperator(nBases, op));
                 buffer = new StringBuffer(4);
 
-                lastOperator = op;
+                prevOp = op;
                 firstOperator = false;
             }
 
@@ -263,23 +275,29 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
 
         alignmentBlocks = new AlignmentBlock[nBlocks];
         insertions = new AlignmentBlock[nInsertions];
-        if (nGaps > 0) {
+        if (nGaps > 0)
+
+        {
             gapTypes = new char[nGaps];
         }
 
-        // fill new arrays
-        int fromIdx = softClippedBaseCount;
-        int blockStart = getStart();
+        // Adjust start and fill new arrays
+        if(showSoftClipped) {
+            start -= softClippedBaseCount;
+        }
+        int fromIdx = showSoftClipped ? 0 : softClippedBaseCount;
+        int blockStart = start;
+
         int blockIdx = 0;
         int insertionIdx = 0;
         int gapIdx = 0;
-        lastOperator = 0;
+        prevOp = 0;
         for (CigarOperator op : operators) {
-            if (op.operator == MATCH || op.operator == PERFECT_MATCH || op.operator == MISMATCH) {
-                byte[] blockBases = new byte[op.nBases];
+            if (operatorIsMatch(showSoftClipped, op.operator)) {
 
+                byte[] blockBases = new byte[op.nBases];
                 byte[] blockQualities = new byte[op.nBases];
-                // Default value
+                //Default value
                 Arrays.fill(blockQualities, (byte) 126);
 
                 // TODO -- represent missing sequence ("*") explicitly rather.
@@ -295,12 +313,16 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                     System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, op.nBases);
                 }
 
-                alignmentBlocks[blockIdx++] = new AlignmentBlock(blockStart, blockBases, blockQualities);
+                AlignmentBlock block = new AlignmentBlock(blockStart, blockBases, blockQualities);
+                if(op.operator == SOFT_CLIP) {
+                    block.setSoftClipped(true);
+                }
+                alignmentBlocks[blockIdx++] = block;
 
                 fromIdx += op.nBases;
                 blockStart += op.nBases;
 
-                if (lastOperator == MATCH || lastOperator == PERFECT_MATCH || lastOperator == MISMATCH) {
+                if (operatorIsMatch(showSoftClipped, prevOp)) {
                     gapTypes[gapIdx++] = ZERO_GAP;
                 }
 
@@ -333,12 +355,28 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
                 fromIdx += op.nBases;
 
             }
-            lastOperator = op.operator;
+            prevOp = op.operator;
         }
 
+        // Check for soft clipping at end
+        if(showSoftClipped && operators.size() > 0 ) {
+            CigarOperator last = operators.get(operators.size()-1);
+            if(last.operator == SOFT_CLIP) {
+                end += last.nBases;
+            }
+        }
+
+
+
+    }
+
+    private boolean operatorIsMatch(boolean showSoftClipped, char operator) {
+        return operator == MATCH || operator == PERFECT_MATCH || operator == MISMATCH
+                || (showSoftClipped && operator == SOFT_CLIP);
     }
 
     // Default constructor to support unit tests
+
     SamAlignment() {
     }
 
@@ -403,19 +441,21 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
     }
 
     public int getStart() {
-        return alignmentStart;
+        return start;
     }
 
     public void setStart(int start) {
+        this.start = start;
         this.alignmentStart = start;
     }
 
     public int getEnd() {
-        return alignmentEnd;
+        return end;
     }
 
     public void setEnd(int end) {
-        this.alignmentEnd = alignmentEnd;
+        this.end = end;
+        this.alignmentEnd = end;
     }
 
     /**
@@ -492,6 +532,12 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
             if (record.getSecondOfPairFlag()) {
                 buf.append("<br>Second in pair");
             }
+            if (record.getNotPrimaryAlignmentFlag()) {
+                buf.append("<br>Alignment NOT primary");
+            }
+            if (record.getReadFailsVendorQualityCheckFlag()) {
+                buf.append("<br>FAILED Vendor Quality Check");
+            }
             buf.append("<br>-------------------");
         }
 
@@ -529,6 +575,10 @@ public class SamAlignment extends AbstractAlignment implements Alignment {
         return pairOrientation;
     }
 
+    public boolean isVendorFailedRead() {
+        return record.getReadFailsVendorQualityCheckFlag();
+    }
+
     static class CigarOperator {
 
         int nBases;
