@@ -164,6 +164,7 @@ public class SessionReader {
         ITEM("item"),
         LOCUS("locus"),
         NAME("name"),
+        SAMPLE_ID("sampleID"),
         RESOURCE_TYPE("resourceType"),
         OPERATOR("operator"),
         RELATIVE_PATH("relativePath"),
@@ -235,11 +236,11 @@ public class SessionReader {
      * @throws RuntimeException
      */
 
-    public Session loadSession(InputStream inputStream, Session session, String sessionName )
+    public Session loadSession(InputStream inputStream, Session session, String sessionName)
             throws RuntimeException {
 
         log.debug("Load session");
-        
+
 
         Document document = null;
         try {
@@ -269,8 +270,6 @@ public class SessionReader {
 
         IGVMainFrame.getInstance().getTrackManager().resetOverlayTracks();
 
-        IGVMainFrame.getInstance().updateAttributePanel();
-
         return session;
     }
 
@@ -466,7 +465,8 @@ public class SessionReader {
 
         // If file is local
         if ((serverURL == null || serverURL.trim().equals("")) &&
-                !filePath.startsWith("http:") && !filePath.startsWith("file:")) {
+                !(filePath.startsWith("http:") || filePath.startsWith("https:") ||
+                        filePath.startsWith("file:"))) {
             String relPathValue = getAttribute(element, SessionAttribute.RELATIVE_PATH.getText());
             boolean relativePaths = ((relPathValue != null) && relPathValue.equalsIgnoreCase("true"));
             File parent = (relativePaths ? new File(session.getPath()).getParentFile() : null);
@@ -502,6 +502,7 @@ public class SessionReader {
 
         String label = getAttribute(element, SessionAttribute.LABEL.getText());
         String name = getAttribute(element, SessionAttribute.NAME.getText());
+        String sampleId = getAttribute(element, SessionAttribute.SAMPLE_ID.getText());
         String description = getAttribute(element, SessionAttribute.DESCRIPTION.getText());
         String type = getAttribute(element, SessionAttribute.TYPE.getText());
         String coverage = getAttribute(element, SessionAttribute.COVERAGE.getText());
@@ -528,6 +529,8 @@ public class SessionReader {
             resourceLocator.setName(label);
         }
 
+        resourceLocator.setSampleId(sampleId);
+
 
         resourceLocator.setDescription(description);
         // This test added to get around earlier bug in the writer
@@ -571,8 +574,7 @@ public class SessionReader {
         String end = getAttribute(element, SessionAttribute.END_INDEX.getText());
         String description = getAttribute(element, SessionAttribute.DESCRIPTION.getText());
 
-        RegionOfInterest region = new RegionOfInterest(chromosome, new Integer(start),
-                new Integer(end), description);
+        RegionOfInterest region = new RegionOfInterest(chromosome, new Integer(start), new Integer(end), description);
         IGVMainFrame.getInstance().addRegionOfInterest(region);
 
         NodeList elements = element.getChildNodes();
@@ -582,8 +584,7 @@ public class SessionReader {
     private void processFilter(Session session, Element element, HashMap additionalInformation) {
 
         String match = getAttribute(element, SessionAttribute.FILTER_MATCH.getText());
-        String showAllTracks = getAttribute(element,
-                SessionAttribute.FILTER_SHOW_ALL_TRACKS.getText());
+        String showAllTracks = getAttribute(element, SessionAttribute.FILTER_SHOW_ALL_TRACKS.getText());
 
         String filterName = getAttribute(element, SessionAttribute.NAME.getText());
         TrackFilter filter = new TrackFilter(filterName, null);
@@ -830,7 +831,7 @@ public class SessionReader {
 
         // TODO -- refactor to remove instanceof / cast.  Currently only ContinuousColorScale is handled
         ColorScale colorScale = ColorScaleFactory.getScaleFromString(value);
-        if(colorScale instanceof ContinuousColorScale) {
+        if (colorScale instanceof ContinuousColorScale) {
             session.setColorScale(trackType, (ContinuousColorScale) colorScale);
         }
 
