@@ -46,8 +46,7 @@ import java.awt.event.ComponentAdapter;
 import java.awt.event.ComponentEvent;
 import java.io.IOException;
 import java.text.NumberFormat;
-import java.util.Collection;
-import java.util.Iterator;
+import java.util.*;
 import java.util.List;
 
 /**
@@ -117,6 +116,8 @@ public class ViewContext {
      */
     private boolean stretched = false;
 
+    public History history;
+
 
     public static ViewContext getInstance() {
         return instance;
@@ -134,6 +135,8 @@ public class ViewContext {
             this.chrName = lastChromosomeViewed;
 
         }
+
+        history = new History(100);
     }
 
     /**
@@ -248,11 +251,18 @@ public class ViewContext {
 
             }
         }
+
+        recordHistory();
+
         // This is a hack,  this is not a drag event but is a "jump"
         DragEventManager.getInstance().dragStopped();
 
     }
 
+    public void recordHistory() {
+        history.push(getCurrentLocusString());
+    }
+
     private void jumpToChromosomeForGenomeLocation(double locationMB) {
         double startMB = 0;
 
@@ -270,14 +280,6 @@ public class ViewContext {
         }
     }
 
-    public void pageLeft() {
-        shiftOriginPixels(-dataPanelWidth);
-    }
-
-    public void pageRight() {
-        shiftOriginPixels(dataPanelWidth);
-    }
-
     /**
      * Method description
      *
@@ -305,7 +307,8 @@ public class ViewContext {
                 setZoom(maxZoom);
             }
         }
-        centerOnLocation(chrLocation);
+        double windowWidth = (dataPanelWidth * getScale()) / 2;
+        setOrigin(Math.round(chrLocation - windowWidth));
     }
 
     /**
@@ -315,8 +318,8 @@ public class ViewContext {
      */
     public void centerOnLocation(double chrLocation) {
         double windowWidth = (dataPanelWidth * getScale()) / 2;
-
         setOrigin(Math.round(chrLocation - windowWidth));
+        recordHistory();
     }
 
     public boolean windowAtEnd() {
@@ -334,9 +337,13 @@ public class ViewContext {
      * @param newOrigin
      */
     public void setOrigin(double newOrigin) {
-        int windowLengthBP = (int) (dataPanelWidth * getScale());
 
-        origin = Math.max(0, Math.min(newOrigin, getChromosomeLength() - windowLengthBP));
+        int windowLengthBP = (int) (dataPanelWidth * getScale());
+        if (PreferenceManager.getInstance().getSAMPreferences().isShowSoftClipped()) {
+            origin = Math.max(-1000, Math.min(newOrigin, getChromosomeLength() + 1000 - windowLengthBP));
+        } else {
+            origin = Math.max(0, Math.min(newOrigin, getChromosomeLength() - windowLengthBP));
+        }
 
         for (TrackPanelScrollPane sp : IGVMainFrame.getInstance().getTrackManager().getTrackPanelScrollPanes()) {
             preloadTrackData(sp.getDataPanel());
@@ -355,17 +362,7 @@ public class ViewContext {
     static double log2 = Math.log(2);
 
     public void jumpTo(String chr, int start, int end) {
-        jumpTo(chr, start, end, true);
 
-    }
-
-    public void jumpTo(String chr, int start, int end, boolean update) {
-
-        //if (log.isDebugEnabled()) {
-        //    log.debug("Jump to: " + chr + ":" + start + "-" + end);
-        //}
-
-        // Switch chromosomes if not null
         if (chr != null) {
             if (genome.getChromosome(chr) == null && !chr.contains(Globals.CHR_ALL)) {
                 JOptionPane.showMessageDialog(IGVMainFrame.getInstance(),
@@ -377,43 +374,35 @@ public class ViewContext {
 
         if (start >= 0) {
 
-            // Estmate zoom level
             int z = (int) (Math.log(getChromosomeLength() / (end - start)) / log2) + 1;
-
             if (z != this.zoom) {
                 zoom = Math.min(maxZoom, Math.max(minZoom, z));
                 nTiles = (int) Math.pow(2, zoom);
                 maxPixel = getTilesTimesBinsPerTile();
             }
 
-            // overide computed scale
             int w = dataPanelWidth;
-            //if (log.isDebugEnabled()) {
-            //    log.debug("W = " + w);
-            //}
-
             setLocationScale(((double) (end - start)) / w);
-
             origin = start;
         }
 
-        if (update) {
 
-            for (TrackPanelScrollPane sp : IGVMainFrame.getInstance().getTrackManager().getTrackPanelScrollPanes()) {
-                preloadTrackData(sp.getDataPanel());
-            }
-
-            if (log.isDebugEnabled()) {
-                log.debug("Data panel width = " + dataPanelWidth);
-                log.debug("New start = " + (int) getOrigin());
-                log.debug("New end = " + (int) getEnd());
-                log.debug("New center = " + (int) getCenter());
-            }
-
-            // Repaint
-            IGVMainFrame.getInstance().repaintDataAndHeaderPanels();
-            IGVMainFrame.getInstance().repaintStatusAndZoomSlider();
+        for (TrackPanelScrollPane sp : IGVMainFrame.getInstance().getTrackManager().getTrackPanelScrollPanes()) {
+            preloadTrackData(sp.getDataPanel());
         }
+
+        if (log.isDebugEnabled()) {
+            log.debug("Data panel width = " + dataPanelWidth);
+            log.debug("New start = " + (int) getOrigin());
+            log.debug("New end = " + (int) getEnd());
+            log.debug("New center = " + (int) getCenter());
+        }
+
+
+        // Repaint
+        IGVMainFrame.getInstance().repaintDataAndHeaderPanels();
+        IGVMainFrame.getInstance().repaintStatusAndZoomSlider();
+
     }
 
     /**
@@ -715,6 +704,10 @@ public class ViewContext {
      */
     public String setGenomeId(String newGenome) {
 
+        if (genomeId != null && !genomeId.equals(newGenome)) {
+            history.clear();
+        }
+
         if (log.isDebugEnabled()) {
             log.debug("Setting genome id: " + newGenome);
         }
@@ -767,6 +760,7 @@ public class ViewContext {
 
             PreferenceManager.getInstance().setDefaultGenome(genomeId);
             this.setChrName(getHomeChr());
+
         } else if (!startUp) {
             // We don't know what chromosomes the new genome has, set to "all" (whole genome)
             this.setChrName(getHomeChr());
@@ -852,19 +846,25 @@ public class ViewContext {
             return getChrName();
         } else {
 
-            int start = 0;
-            int end = getDataPanelWidth();
-            int startLoc = (int) getChromosomePosition(start) + 1;
-            int endLoc = (int) getChromosomePosition(end);
-            String startStr = NumberFormat.getInstance().format(startLoc);
-            String endStr = NumberFormat.getInstance().format(endLoc);
-            String position = getChrName() + ":" + startStr + "-" + endStr;
+            Range range = getCurrentRange();
+            String startStr = NumberFormat.getInstance().format(range.getStart());
+            String endStr = NumberFormat.getInstance().format(range.getEnd());
+            String position = range.getChr() + ":" + startStr + "-" + endStr;
 
             return position;
         }
 
     }
 
+    public Range getCurrentRange() {
+        int start = 0;
+        int end = getDataPanelWidth();
+        int startLoc = (int) getChromosomePosition(start) + 1;
+        int endLoc = (int) getChromosomePosition(end);
+        Range range = new Range(getChrName(), startLoc, endLoc);
+        return range;
+    }
+
     private void setLocationScale(double locationScale) {
         this.locationScale = locationScale;
         locationScaleValid = true;
@@ -905,8 +905,8 @@ public class ViewContext {
 
 
                     if (track.isVisible()) {
-                        track.preloadData(chrName, start, end, zoom);
-
+                    //    track.preloadData(chrName, start, end, zoom);
+                    //
                         trackY += track.getHeight();
                     }
                 }
@@ -914,4 +914,115 @@ public class ViewContext {
 
         }
     }
+
+    public List<String> getAllHistory() {
+        return history.getAllHistory();
+    }
+
+    public static class Range {
+        private String chr;
+        private int start;
+        private int end;
+
+        public Range(String chr, int start, int end) {
+            this.chr = chr;
+            this.start = start;
+            this.end = end;
+        }
+
+        public String getChr() {
+            return chr;
+        }
+
+        public int getStart() {
+            return start;
+        }
+
+        public int getEnd() {
+            return end;
+        }
+    }
+
+    public static class History {
+
+        int maxEntries = 100;
+        int currPos = 0;
+
+        LinkedList<String> activeStack;
+        List<String> allHistory;
+
+        History(int maxEntries) {
+            this.maxEntries = maxEntries;
+            activeStack = new LinkedList();
+            allHistory = new ArrayList();
+        }
+
+
+        public void push(String s) {
+
+            log.debug("History: " + s);
+            allHistory.add(s);
+
+            while (currPos > 0) {
+                activeStack.removeFirst();
+                currPos--;
+            }
+            activeStack.addFirst(s);
+
+
+        }
+
+
+        public String back() {
+            if (activeStack.size() == 0 || currPos >= (activeStack.size() - 1)) {
+                return null;
+            }
+            currPos++;
+            return activeStack.get(currPos);
+        }
+
+        public String forward() {
+
+            if (activeStack.size() == 0 || currPos == 0) {
+                return null;
+            }
+            currPos--;
+            printStack();
+            return activeStack.get(currPos);
+        }
+
+
+        public String peekBack() {
+            if (activeStack.size() == 0 || (currPos + 1) >= activeStack.size()) {
+                return null;
+            }
+            return activeStack.get(currPos + 1);
+        }
+
+        public String peekForward() {
+            if (activeStack.size() == 0 || (currPos - 1) < 0) {
+                return null;
+            }
+            return activeStack.get(currPos - 1);
+        }
+
+        public void clear() {
+            activeStack.clear();
+            allHistory.clear();
+            currPos = 0;
+        }
+
+        public void printStack() {
+            System.out.println("curr pos=" + currPos);
+            for (String s : activeStack) {
+                System.out.println(s);
+            }
+            System.out.println();
+        }
+
+        public List<String> getAllHistory() {
+            return allHistory;
+        }
+
+    }
 }
