@@ -41,8 +41,10 @@ import org.broad.tribble.index.interval.IntervalIndexCreator;
 import org.broad.tribble.index.linear.LinearIndex;
 import org.broad.tribble.index.linear.LinearIndexCreator;
 
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -55,24 +57,24 @@ import java.util.List;
  */
 public class IgvTools {
 
-    static int MAX_RECORDS_IN_RAM = 500000;
-    static String version = "@VERSION";
+    static String version = "1.5.7";
 
     static String[] commandDocs = new String[]{
             "version print the version number",
             "sort    sort an alignment file by start position",
             "index   index an alignment file",
-            "tile    convert an cn input file (cn, gct, wig) to tiled data format",
+            "tile    convert an input file (cn, gct, wig) to tiled data format (tdf)",
             "count   compute coverage density for an alignment file"
     };
-    private static final int MAX_ZOOM = 7;
-    private static final int WINDOW_SIZE = 25;
-    private static final int EXT_FACTOR = 0;
-    private static final Object PROBE_FILE = null;
-    private static final int LINEAR_BIN_SIZE = 16000;
-    private static final int INTERVAL_SIZE = 1000;
-    private static final int LINEAR_INDEX = 1;
-    private static final int INTERVAL_INDEX = 2;
+     static final int MAX_RECORDS_IN_RAM = 500000;
+     static final int MAX_ZOOM = 7;
+     static final int WINDOW_SIZE = 25;
+     static final int EXT_FACTOR = 0;
+     static final Object PROBE_FILE = null;
+     static final int LINEAR_BIN_SIZE = 16000;
+     static final int INTERVAL_SIZE = 1000;
+     static final int LINEAR_INDEX = 1;
+     static final int INTERVAL_INDEX = 2;
 
     /**
      * The general usage string
@@ -96,12 +98,14 @@ public class IgvTools {
         Globals.setHeadless(true);
 
         CmdLineParser parser = new CmdLineParser();
+        CmdLineParser.Option helpOption = parser.addBooleanOption('h', "help");
+        CmdLineParser.Option guiOption = parser.addBooleanOption('g', "gui");
         CmdLineParser.Option windowFunctions = parser.addStringOption('f', "windowFunctions");
         CmdLineParser.Option tmpDirOption = parser.addStringOption('t', "tmpDir");
         CmdLineParser.Option probeFileOption = parser.addStringOption('p', "probeFile");
         CmdLineParser.Option maxZoomOption = parser.addIntegerOption('z', "maxZoom");
         CmdLineParser.Option compressOption = parser.addBooleanOption('c', "compressed");
-        CmdLineParser.Option maxRecordsOption = parser.addStringOption('m', "maxRecords");
+        CmdLineParser.Option maxRecordsOption = parser.addIntegerOption('m', "maxRecords");
 
         // options for coverage counter
         CmdLineParser.Option windowSizeOption = parser.addIntegerOption('w', "windowSize");
@@ -116,12 +120,7 @@ public class IgvTools {
         CmdLineParser.Option strandOption = parser.addIntegerOption('s', "strand");
         CmdLineParser.Option unOrdered = parser.addBooleanOption('u', "unOrdered");
 
-        if (argv.length < 1) {
-            System.out.println("Args: " + argv.length);
-            System.out.println(usageString());
-            System.exit(-1);
-        }
-
+        
         // Parse optional arguments (switches, etc)
         try {
             parser.parse(argv);
@@ -129,6 +128,22 @@ public class IgvTools {
             System.err.println(e.getMessage());
             return;
         }
+
+        boolean help = ((Boolean) parser.getOptionValue(helpOption, false));
+        if(argv.length < 1 || help) {
+            System.out.println(usageString());
+            return;
+        }
+
+
+        boolean gui = ((Boolean) parser.getOptionValue(guiOption, false));
+        if(gui) {
+            launchGUI();
+            Runtime.getRuntime().halt(0);
+        }
+
+
+
         int maxZoomValue = (Integer) parser.getOptionValue(maxZoomOption, MAX_ZOOM);
         int windowSizeValue = (Integer) parser.getOptionValue(windowSizeOption, WINDOW_SIZE);
         int extFactorValue = (Integer) parser.getOptionValue(extFactorOption, EXT_FACTOR);
@@ -174,13 +189,13 @@ public class IgvTools {
                 //    ofile = ofile + ".tdf";
                 //}
                 String genomeId = nonOptionArgs[3];
+                boolean isGCT = Preprocessor.getExtension(ifile).endsWith("gct");
+                Collection<WindowFunction> wfList = parseWFS(wfsString, isGCT);
 
                 if (command.equals("count")) {
-                    doCount(ifile, ofile, genomeId, maxZoomValue, wfsString, windowSizeValue, extFactorValue,
-                            strandOptionValue);
-
+                    doCount(ifile, ofile, genomeId, maxZoomValue, wfList, windowSizeValue, extFactorValue, strandOptionValue);
                 } else {
-                    doTile(ifile, ofile, probeFile, genomeId, maxZoomValue, wfsString);
+                    doTile(ifile, ofile, probeFile, genomeId, maxZoomValue, wfList);
                 }
             } else if (command.toLowerCase().equals("sort")) {
                 validateArgsLength(nonOptionArgs, 3);
@@ -216,8 +231,20 @@ public class IgvTools {
     }
 
     public static void doTile(String ifile, String ofile, String probeFile, String genomeId, int maxZoomValue,
-                              String wfsString) throws IOException, PreprocessingException {
+                              Collection<WindowFunction> windowFunctions) throws IOException, PreprocessingException {
         validateIsTilable(ifile);
+
+        System.out.println("Tile.  File = " + ifile);
+        System.out.println("Max zoom = " + maxZoomValue);
+        if(probeFile != null && probeFile.trim().length() > 0) {
+            System.out.println("Probe file = " + probeFile);
+        }
+        System.out.print("Window functions: ");
+        for(WindowFunction wf : windowFunctions) {
+            System.out.print(wf.toString() + " ");
+        }
+        System.out.println();
+
         Genome genome = loadGenome(genomeId);
         if (genome == null) {
             throw new PreprocessingException("Genome could not be loaded: " + genomeId);
@@ -227,10 +254,6 @@ public class IgvTools {
         // TODO -- do a better size estimate for directories
         int nLines = tmp.isDirectory() ? 310000000 : ParsingUtils.estimateLineCount(ifile);
 
-        boolean isGCT = Preprocessor.getExtension(ifile).endsWith("gct");
-
-        Collection<WindowFunction> windowFunctions = parseWFS(wfsString, isGCT);
-
         Preprocessor p = new Preprocessor(new File(ofile), genome, windowFunctions, nLines, null);
         if (tmp.isDirectory()) {
             for (File f : tmp.listFiles()) {
@@ -241,10 +264,25 @@ public class IgvTools {
         }
         p.finish();
 
+        System.out.flush();
+
     }
 
-    public static void doCount(String ifile, String ofile, String genomeId, int maxZoomValue, String wfsString,
+    public static void doCount(String ifile, String ofile, String genomeId, int maxZoomValue,
+                               Collection<WindowFunction> windowFunctions,
                                int windowSizeValue, int extFactorValue, int strandOption) throws IOException {
+        System.out.println("Computing coverage.  File = " + ifile);
+        System.out.println("Max zoom = " + maxZoomValue);
+        System.out.println("Window size = " + windowSizeValue);
+        System.out.print("Window functions: ");
+        for(WindowFunction wf : windowFunctions) {
+            System.out.print(wf.toString() + " ");
+        }
+        System.out.println();
+        System.out.println("Ext factor = " + extFactorValue);
+
+
+
         Genome genome = loadGenome(genomeId);
         if (genome == null) {
             throw new PreprocessingException("Genome could not be loaded: " + genomeId);
@@ -255,10 +293,10 @@ public class IgvTools {
         File tdfFile = null;
         File wigFile = null;
         String[] files = ofile.split(",");
-        if (files[EXT_FACTOR].endsWith("wig")) {
-            wigFile = new File(files[EXT_FACTOR]);
+        if (files[0].endsWith("wig")) {
+            wigFile = new File(files[0]);
         } else {
-            tdfFile = new File(files[EXT_FACTOR]);
+            tdfFile = new File(files[0]);
         }
         if (files.length > 1) {
             if (files[1].endsWith("wig")) {
@@ -268,12 +306,15 @@ public class IgvTools {
             }
         }
 
-        boolean isGCT = Preprocessor.getExtension(ifile).endsWith("gct");
-        Collection<WindowFunction> windowFunctions = parseWFS(wfsString, isGCT);
+        if(!tdfFile.getName().endsWith(".tdf")) {
+            tdfFile = new File(tdfFile.getAbsolutePath() + ".tdf");
+        }
 
         Preprocessor p = new Preprocessor(tdfFile, genome, windowFunctions, nLines, null);
         p.count(ifile, windowSizeValue, extFactorValue, maxZoomValue, wigFile, strandOption);
         p.finish();
+
+        System.out.flush();
     }
 
 
@@ -299,12 +340,12 @@ public class IgvTools {
     public static void doIndex(String ifile, int indexType, int binSize) throws IOException {
         if (ifile.endsWith(".gz")) {
             System.out.println("Cannot index a gzipped file");
-            System.exit(-1);
+            throw new PreprocessingException("Cannot index a gzipped file");
         }
 
         File inputFile = new File(ifile);
         if (ifile.endsWith(".bed") || ifile.endsWith(".vcf") || ifile.endsWith(".gff") ||
-                ifile.endsWith(".gff3")) {
+                ifile.endsWith(".gff3")|| ifile.endsWith(".psl") || ifile.endsWith(".pslx")) {
             FeatureCodec codec = CodecFactory.getCodec(ifile);
 
             IndexCreator indexer = null;
@@ -313,7 +354,7 @@ public class IgvTools {
                 c.setBinWidth(binSize);
                 indexer = c;
             } else {
-                IntervalIndexCreator c  = new IntervalIndexCreator(inputFile, codec);
+                IntervalIndexCreator c = new IntervalIndexCreator(inputFile, codec);
                 c.setFeaturesPerInterval(binSize);
                 indexer = c;
             }
@@ -324,27 +365,30 @@ public class IgvTools {
             AlignmentIndexer indexer = AlignmentIndexer.getInstance(inputFile, null, null);
             indexer.createSamIndex();
         }
+        System.out.flush();
 
     }
 
 
     public static void doSort(String ifile, String ofile, String tmpDirName, int maxRecords) {
 
+        System.out.println("Sorting " + ifile);
         File inputFile = new File(ifile);
         File outputFile = new File(ofile);
         Sorter sorter = Sorter.getSorter(inputFile, outputFile);
-
-        if (tmpDirName != null) {
+        if (tmpDirName != null && tmpDirName.trim().length() > 0) {
             File tmpDir = new File(tmpDirName);
             if (!tmpDir.exists()) {
                 System.err.println("Error: tmp directory: " + tmpDir.getAbsolutePath() + " does not exist.");
-                System.exit(-1);
+                throw new PreprocessingException("Error: tmp directory: " + tmpDir.getAbsolutePath() + " does not exist.");
             }
             sorter.setTmpDir(tmpDir);
         }
 
         sorter.setMaxRecords(maxRecords);
         sorter.run();
+        System.out.println("Done");
+        System.out.flush();
     }
 
 
@@ -356,9 +400,16 @@ public class IgvTools {
 
 
     private static Genome loadGenome(String genomeFileOrID) {
+        
 
         String rootDir = FileUtils.getInstallDirectory();
 
+        Genome genome = GenomeManager.getInstance().getGenome(genomeFileOrID);
+        if(genome != null) {
+            return genome;
+        }
+
+
         File genomeFile = new File(rootDir, "genomes" + File.separator + genomeFileOrID + ".genome");
         if (!genomeFile.exists()) {
             genomeFile = new File(rootDir, "genomes" + File.separator + genomeFileOrID);
@@ -376,7 +427,7 @@ public class IgvTools {
             throw new PreprocessingException("Error loading: " + genomeFileOrID);
         }
         ViewContext.getInstance().setGenomeId(genomeId);
-        Genome genome = GenomeManager.getInstance().getGenome(genomeId);
+        genome = GenomeManager.getInstance().getGenome(genomeId);
         return genome;
     }
 
@@ -438,5 +489,9 @@ public class IgvTools {
     }
 
 
+    private static void launchGUI() {
+        IgvToolsGui.main(null);
+    }
+
 }
 
