@@ -26,7 +26,7 @@ package org.broad.igv.tools;
 /**
  * @author jrobinso
  */
-class PreprocessingException extends RuntimeException {
+public class PreprocessingException extends RuntimeException {
 
     public PreprocessingException(String msg) {
         super(msg);
