@@ -80,7 +80,7 @@ public class GCTParser extends AbstractParser {
         this.dataFileLocator = resFile;
         this.genome = genome;
         this.geneManager = GeneManager.getGeneManager(genome);
-        if (probeFile != null) {
+        if (probeFile != null && probeFile.trim().length() > 0) {
             BEDFileParser parser = new BEDFileParser();
             ResourceLocator rl = new ResourceLocator(probeFile);
             AsciiLineReader reader = ParsingUtils.openAsciiReader(rl);
@@ -337,10 +337,7 @@ public class GCTParser extends AbstractParser {
             int[] ends = getEndLocations(chr);
             String[] name = getNames(chr);
             for (int i = 0; i < starts.length; i++) {
-                float[] data = new float[columnHeadings.length];
-                for (int c = 0; c < columnHeadings.length; c++) {
-                    data[c] = getData(columnHeadings[c], chr)[i];
-                }
+                float[] data = getData(chr, i);
                 getDataConsumer().addData(chr, starts[i], ends[i], data, name[i]);
             }
         }
@@ -394,11 +391,6 @@ public class GCTParser extends AbstractParser {
             }
         }
 
-
-        // and to loop through the list
-        if (log.isDebugEnabled()) {
-            log.debug("Searching probeToGene map");
-        }
         String[] loci = ProbeToGeneMap.getInstance().getGenesForProbe(probeId);
 
         if (loci != null) {
@@ -406,11 +398,6 @@ public class GCTParser extends AbstractParser {
                 Locus locus = getLocus(locusString);
                 //Feature gene = FeatureDB.getFeature(locusString);
 
-                if (log.isDebugEnabled()) {
-                    log.debug(locusString + " -> " + locus);
-                }
-
-
                 if (locus != null) {
                     addRow(probeId, locus, values);
                 }
@@ -493,19 +480,13 @@ public class GCTParser extends AbstractParser {
         return names;
     }
 
-    private float[] getData(String heading, String chr) {
-
-        int columnIndex = this.headingIndexMap.get(heading);
-        List<Row> rows = rowMap.get(chr);
-
-        float[] data = new float[rows.size()];
-        for (int i = 0; i < rows.size(); i++) {
-            data[i] = rows.get(i).values[columnIndex];
-        }
+    private float[] getData(String chr, int row) {
+       List<Row> rows = rowMap.get(chr);
+        float[] data =  rows.get(row).values;
         return data;
-
     }
 
+
     /**
      * Search for a locus explicitly specified in the description field.
      * A locus can be specified either directrly, as a UCSC style locus string
