@@ -17,8 +17,8 @@
  */
 package org.broad.igv.track;
 
-import net.sf.samtools.util.CloseableIterator;
 import org.apache.log4j.Logger;
+import org.broad.igv.Globals;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.*;
 import org.broad.igv.renderer.*;
@@ -57,12 +57,13 @@ public class FeatureTrack extends AbstractTrack {
 
     protected FeatureSource source;
     private static final int MINIMUM_FEATURE_SPACING = 1;
-    private int featureVisibilityWindow = Integer.MAX_VALUE;
+    private int visibilityWindow = -1;
 
     private Rectangle expandButtonRect = expandButtonRect = new Rectangle();
     private static final int EXPAND_ICON_BUFFER_WIDTH = 17;
     private static final int EXPAND_ICON_BUFFER_HEIGHT = 17;
     public static final int MARGIN = 5;
+    public static final String FEATURE_VISIBILITY_WINDOW = "featureVisibilityWindow";
 
 
     public FeatureTrack(String id, FeatureSource source) {
@@ -85,7 +86,7 @@ public class FeatureTrack extends AbstractTrack {
         coverageRenderer = new HeatmapRenderer();
 
         if(source.getBinSize() > 0) {
-            featureVisibilityWindow = source.getBinSize();
+            visibilityWindow = source.getBinSize();
         }
         else {
 
@@ -97,7 +98,7 @@ public class FeatureTrack extends AbstractTrack {
         super.setTrackProperties(trackProperties);
 
         if (trackProperties.getFeatureVisibilityWindow() > 0) {
-            setFeatureVisibilityWindow(trackProperties.getFeatureVisibilityWindow());
+            setVisibilityWindow(trackProperties.getFeatureVisibilityWindow());
         }
 
     }
@@ -304,17 +305,25 @@ public class FeatureTrack extends AbstractTrack {
 
  
         double windowSize = rect.width * context.getScale();
-        
-        showFeatures = (windowSize < featureVisibilityWindow()) ;
+
+        int vw = getVisibilityWindow();
+        showFeatures = true;
+        if(vw == 0) {
+            showFeatures = !context.getChr().equals(Globals.CHR_ALL);
+        }
+        else if(vw > 0) {
+            showFeatures = !context.getChr().equals(Globals.CHR_ALL) && windowSize <= vw;
+        }
 
         if (showFeatures) {
             renderFeatures(context, renderRect);
-            if (!IGVMainFrame.getInstance().isExportingSnapshot()) {
-                renderExpandTool(context, rect);
-            }
         } else {
             renderCoverage(context, renderRect);
         }
+        boolean showIcon = PreferenceManager.getInstance().getBooleanPreference(PreferenceManager.SHOW_EXPAND_ICON, true);
+        if (showIcon && !IGVMainFrame.getInstance().isExportingSnapshot()) {
+            renderExpandTool(context, rect);
+        }
     }
 
     private void renderCoverage(RenderContext context, Rectangle inputRect) {
@@ -324,12 +333,27 @@ public class FeatureTrack extends AbstractTrack {
             Graphics2D g = context.getGraphic2DForColor(Color.gray);
             GraphicUtils.drawCenteredText("Zoom in to see features.", inputRect, g);
         } else {
-            setDataRange(new DataRange(0, 0, 20)); //1.2f * (float) source.getCoverageSource().getDataMax()));
+            float max = getMaxEstimate(scores);
+            ContinuousColorScale cs = getColorScale();
+            if (cs != null) {
+                cs.setPosEnd(max);
+            }
+            setDataRange(new DataRange(0, 0, max));
             coverageRenderer.render(this, scores, context, inputRect);
         }
     }
 
 
+    private float getMaxEstimate(List<LocusScore> scores) {
+        float max = 0;
+        int n = Math.min(200, scores.size());
+        for (int i = 0; i < n; i++) {
+            max = Math.max(max, scores.get(i).getScore());
+        }
+        return max;
+    }
+
+
     private boolean featuresLoading = false;
 
 
@@ -607,25 +631,25 @@ public class FeatureTrack extends AbstractTrack {
         return f;
     }
 
-    public int featureVisibilityWindow() {
-        return featureVisibilityWindow;
+    public int getVisibilityWindow() {
+        return visibilityWindow;
     }
 
-    public void setFeatureVisibilityWindow(int windowSize) {
-        this.featureVisibilityWindow = windowSize;
-        source.setBinSize(featureVisibilityWindow);
+    public void setVisibilityWindow(int windowSize) {
+        this.visibilityWindow = windowSize;
+        source.setBinSize(visibilityWindow);
     }
 
     @Override
     public void restorePersistentState(Map<String, String> attributes) {
         super.restorePersistentState(attributes);    //To change body of overridden methods use File | Settings | File Templates.
 
-        String fvw = attributes.get("featureVisibilityWindow");
-        if(fvw != null) {
+        String fvw = attributes.get(FEATURE_VISIBILITY_WINDOW);
+        if (fvw != null) {
             try {
-                featureVisibilityWindow = Integer.parseInt(fvw);
+                visibilityWindow = Integer.parseInt(fvw);
             } catch (NumberFormatException e) {
-                log.error("Error restoring featureVisibilityWindow: " + fvw);
+                log.error("Error restoring visibilityWindow: " + fvw);
             }
         }
 
@@ -633,10 +657,10 @@ public class FeatureTrack extends AbstractTrack {
 
     @Override
     public Map<String, String> getPersistentState() {
-        Map<String, String> stateMap =  super.getPersistentState();
-        stateMap.put("featureVisibilityWindow", String.valueOf(featureVisibilityWindow));
+        Map<String, String> stateMap = super.getPersistentState();
+        stateMap.put(FEATURE_VISIBILITY_WINDOW, String.valueOf(visibilityWindow));
         return stateMap;
-        
+
     }
 
     //public Feature nextFeature(String chr, double position, boolean forward) {
