@@ -27,5 +27,5 @@ package org.broad.igv.track;
  * @author jrobinso
  */
 public enum RegionScoreType {
-    AMPLIFICATION, DELETION, EXPRESSION, SCORE
+    AMPLIFICATION, DELETION, EXPRESSION, SCORE, FLUX
 }
