@@ -45,6 +45,7 @@ import org.broad.igv.tdf.TDFDataSource;
 import org.broad.igv.tdf.TDFReader;
 import org.broad.igv.track.tribble.TribbleFeatureSource;
 import org.broad.igv.ui.IGVMainFrame;
+import org.broad.igv.ui.util.ConfirmDialog;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.IGVHttpUtils;
 import org.broad.igv.util.ParsingUtils;
@@ -53,7 +54,6 @@ import org.broad.igv.util.ResourceLocator;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
@@ -100,8 +100,12 @@ public class TrackLoader {
                 loadDASResource(locator, newTracks);
             } else if (isIndexed(locator.getPath())) {
                 loadIndexed(locator, newTracks);
-                //} else if (typeString.endsWith("dot")) {
-                //    loadDOTFile(locator, newTracks);
+
+
+            } else if (typeString.endsWith("vcf")) {
+                // TODO This is a hack,  vcf files must be indexed.  Fix in next release.
+                throw new DataLoadException("VCF files must be indexed.  Use igvtools or tabix to index the file prior to loading.",
+                        locator.getPath());
             } else if (typeString.endsWith("h5") || typeString.endsWith("hbin")) {
                 loadH5File(locator, newTracks);
             } else if (typeString.endsWith("rnai.gct")) {
@@ -156,8 +160,19 @@ public class TrackLoader {
             } else if (IGVDatasetParser.parsableMAGE_TAB(locator)) {
                 locator.setDescription("MAGE_TAB");
                 loadIGVFile(locator, newTracks);
-            } else {
+            } else if (typeString.endsWith(".psl") || typeString.endsWith(".psl.gz") ||
+                    typeString.endsWith(".pslx") || typeString.endsWith(".pslx.gz")) {
+                loadPslFile(locator, newTracks);
+            } else if(AbstractFeatureParser.getInstanceFor(locator) != null) {
                 loadFeatureFile(locator, newTracks);
+            } else if (MutationParser.isMutationAnnotationFile(locator)) {
+                this.loadMutFile(locator, newTracks);
+            } else if (WiggleParser.isWiggle(locator)) {
+                loadWigFile(locator, newTracks);
+            } else if (locator.getPath().toLowerCase().contains(".maf")) {
+                loadMAFTrack(locator, newTracks);
+            } else {
+                AttributeManager.getInstance().loadSampleInfo(locator);
             }
 
             // Track line
@@ -180,6 +195,9 @@ public class TrackLoader {
                 if (locator.getColor() != null) {
                     track.setColor(locator.getColor());
                 }
+                if(locator.getSampleId() != null) {
+                    track.setSampleId(locator.getSampleId());
+                }
                 IGVMainFrame.getInstance().getTrackManager().addLoadedType(track.getTrackType());
             }
 
@@ -228,8 +246,10 @@ public class TrackLoader {
     private void loadGeneFile(ResourceLocator locator, List<Track> newTracks) {
 
         FeatureParser featureParser = AbstractFeatureParser.getInstanceFor(locator);
-        List<FeatureTrack> tracks = featureParser.loadTracks(locator);
-        newTracks.addAll(tracks);
+        if (featureParser != null) {
+            List<FeatureTrack> tracks = featureParser.loadTracks(locator);
+            newTracks.addAll(tracks);
+        }
 
     }
 
@@ -250,6 +270,25 @@ public class TrackLoader {
         newTracks.addAll(parser.loadTracks(locator));
     }
 
+    /**
+     * Load the input file as a feature, muation, or maf (multiple alignment) file.
+     *
+     * @param locator
+     * @param newTracks
+     */
+    private void loadPslFile(ResourceLocator locator, List<Track> newTracks) throws IOException {
+
+        PSLParser featureParser = new PSLParser();
+        List<FeatureTrack> tracks = featureParser.loadTracks(locator);
+        newTracks.addAll(tracks);
+        for (Track t : tracks) {
+            ((FeatureTrack) t).setMinimumHeight(10);
+            t.setHeight(30);
+            t.setExpanded(true);
+        }
+
+
+    }
 
     /**
      * Load the input file as a feature, muation, or maf (multiple alignment) file.
@@ -259,8 +298,16 @@ public class TrackLoader {
      */
     private void loadFeatureFile(ResourceLocator locator, List<Track> newTracks) throws IOException {
 
+        if (locator.isLocal() && (locator.getPath().endsWith(".bed") ||
+                locator.getPath().endsWith(".bed.txt") ||
+                locator.getPath().endsWith(".bed.gz"))) {
+            if (!checkSize(locator.getPath())) {
+                return;
+            }
+        }
+
         FeatureParser featureParser = AbstractFeatureParser.getInstanceFor(locator);
-        if (featureParser.isFeatureFile(locator)) {
+        if (featureParser != null) {
             List<FeatureTrack> tracks = featureParser.loadTracks(locator);
             newTracks.addAll(tracks);
         } else if (MutationParser.isMutationAnnotationFile(locator)) {
@@ -271,6 +318,8 @@ public class TrackLoader {
             loadMAFTrack(locator, newTracks);
         }
 
+
+
     }
 
     /**
@@ -310,6 +359,12 @@ public class TrackLoader {
 
     private void loadGctFile(ResourceLocator locator, List<Track> newTracks) {
 
+        if (locator.isLocal()) {
+            if (!checkSize(locator.getPath())) {
+                return;
+            }
+        }
+
         GCTDatasetParser parser = null;
         GCTDataset ds = null;
 
@@ -352,11 +407,17 @@ public class TrackLoader {
 
     private void loadIGVFile(ResourceLocator locator, List<Track> newTracks) {
 
+        if (locator.isLocal()) {
+            if (!checkSize(locator.getPath())) {
+                return;
+            }
+        }
+
+
         String dsName = locator.getTrackName();
-
         String currentGenomeId = ViewContext.getInstance().getGenomeId();
-        IGVDataset ds = new IGVDataset(currentGenomeId, locator);
 
+        IGVDataset ds = new IGVDataset(currentGenomeId, locator);
         ds.setName(dsName);
 
         TrackProperties trackProperties = ds.getTrackProperties();
@@ -381,6 +442,49 @@ public class TrackLoader {
         }
     }
 
+    private boolean checkSize(String file) {
+
+        if (!PreferenceManager.getInstance().getBooleanPreference(PreferenceManager.SHOW_SIZE_WARNING, true)) {
+            return true;
+        }
+
+        File f = new File(file);
+        String tmp = file;
+        if (f.exists()) {
+            long size = f.length();
+            if (file.endsWith(".gz")) {
+                size *= 3;
+                tmp = file.substring(0, file.length() - 3);
+            }
+
+            if (size > 50000000) {
+                String message = "";
+                if (tmp.endsWith(".bed") || tmp.endsWith(".bed.txt")) {
+                    message = "The file " + file + " is large (" + (size / 1000000) + " mb).  It is recommended " +
+                            "that large files be indexed using IGVTools or Tabix. Loading un-indexed " +
+                            "ascii fies of this size can lead to poor performance or unresponsiveness (freezing).  " +
+                            "<br><br>IGVTools can be launched from the <b>Tools</b> menu or separately as a command line program.  " +
+                            "See the user guide for more details.<br><br>Click <b>Continue</b> to continue loading, or <b>Cancel</b>" +
+                            " to skip this file.";
+
+                } else {
+
+                    message = "The file " + file + " is large (" + (size / 1000000) + " mb).  It is recommended " +
+                            "that large files be converted to the binary <i>.tdf</i> format using the IGVTools " +
+                            "<b>tile</b> command. Loading  unconverted ascii fies of this size can lead to poor " +
+                            "performance or unresponsiveness (freezing).  " +
+                            "<br><br>IGVTools can be launched from the <b>Tools</b> menu or separately as a " +
+                            "command line program. See the user guide for more details.<br><br>Click <b>Continue</b> " +
+                            "to continue loading, or <b>Cancel</b> to skip this file.";
+                }
+
+                return ConfirmDialog.optionallyShowInfoDialog(message, PreferenceManager.SHOW_SIZE_WARNING, true);
+
+            }
+        }
+        return true;
+    }
+
     private void loadDOTFile(ResourceLocator locator, List<Track> newTracks) {
 
         //GraphTrack gt = new GraphTrack(locator);
@@ -391,6 +495,12 @@ public class TrackLoader {
 
     private void loadWigFile(ResourceLocator locator, List<Track> newTracks) {
 
+        if (locator.isLocal()) {
+            if (!checkSize(locator.getPath())) {
+                return;
+            }
+        }
+
         String genome = ViewContext.getInstance().getGenomeId();
 
         WiggleDataset ds = (new WiggleParser(locator, genome)).parse();
@@ -505,7 +615,7 @@ public class TrackLoader {
             FeatureSource source = new FeatureDirSource(locator);
             FeatureTrack track = new FeatureTrack(locator, source);
             track.setName(locator.getTrackName());
-            track.setFeatureVisibilityWindow(100000);
+            track.setVisibilityWindow(100000);
             newTracks.add(track);
         } catch (IOException ex) {
             throw new RuntimeException(ex);
@@ -691,8 +801,10 @@ public class TrackLoader {
             }
             if (covPath != null) {
                 try {
-                    if ((new File(covPath)).exists() || (covPath.startsWith("http") &&
-                            IGVHttpUtils.resourceAvailable(new URL(covPath)))) {
+                    // TODO -- ftp
+                    if ((new File(covPath)).exists() ||
+                            ((covPath.startsWith("http:") || covPath.startsWith("https:")) &&
+                                    IGVHttpUtils.resourceAvailable(new URL(covPath)))) {
                         TDFReader reader = TDFReader.getReader(covPath);
                         TDFDataSource ds = new TDFDataSource(reader, 0, track.getName() + " coverage");
                         covTrack.setDataSource(ds);
@@ -704,7 +816,6 @@ public class TrackLoader {
             }
 
             newTracks.add(track);
-            track.preloadData();
 
         } catch (Exception e) {
             log.error("Error loading sam track", e);
@@ -735,6 +846,7 @@ public class TrackLoader {
         // TODO - -handle remote resource
         SegmentedAsciiDataSet ds = new SegmentedAsciiDataSet(locator);
         String path = locator.getPath();
+        TrackProperties props = ds.getTrackProperties(); 
         for (String trackName : ds.getDataHeadings()) {
             String trackId = path + "_" + trackName;
             SegmentedDataSource dataSource = new SegmentedDataSource(trackName, ds);
@@ -742,6 +854,11 @@ public class TrackLoader {
             track.setId_142(trackName);
             track.setRendererClass(HeatmapRenderer.class);
             track.setTrackType(ds.getType());
+
+            if(props != null) {
+                track.setTrackProperties(props);
+            }
+
             newTracks.add(track);
         }
     }
@@ -792,7 +909,8 @@ public class TrackLoader {
         String indexExtension = path.endsWith("gz") ? ".tbi" : ".idx";
         String indexPath = path + indexExtension;
         try {
-            if (path.startsWith("http:")) {
+            // TODO -- ftp
+            if (path.startsWith("http:") || path.startsWith("https:")) {
                 return IGVHttpUtils.resourceAvailable(new URL(indexPath));
             } else {
                 File f = new File(path + indexExtension);
