@@ -163,14 +163,6 @@ public class TrackManager {
         }
     }
 
-    public void preloadSAMTracks() {
-        for (Track t : getAllTracks(false)) {
-            if (t instanceof AlignmentTrack) {
-                ((AlignmentTrack) t).preloadData();
-            }
-        }
-    }
-
     public void sortAlignmentTracks(AlignmentTrack.SortOption option) {
         for (Track t : getAllTracks(false)) {
             if (t instanceof AlignmentTrack) {
@@ -252,7 +244,7 @@ public class TrackManager {
 
         //TODO Throw the message window higher up. There should be a throw when you are using the UI,
         // not when you are connecting through Socket
-        IGVMainFrame.getInstance().updateAttributePanel();
+
         if (!messages.isEmpty()) {
             for (String message : messages.getMessages()) {
                 MessageUtils.showMessage(message);
@@ -281,10 +273,7 @@ public class TrackManager {
 
 
                 }
-            } else {
-                loadAttributeFile(locator);
-            }
-
+            } 
             return newTracks;
 
         } catch (DataLoadException dle) {
@@ -600,17 +589,6 @@ public class TrackManager {
         }
     }
 
-    /**
-     * Load the input file as a BED or Attribute (Sample Info) file.  First assume
-     * it is a BED file,  if no features are found load as an attribute file.
-     *
-     * @param locator
-     */
-    private void loadAttributeFile(ResourceLocator locator) {
-        AttributeManager.getInstance().loadSampleInfo(locator);
-    }
-
-
     /**
      * Sort all groups (data and feature) by a computed score over a region.  The
      * sort is done twice (1) groups are sorted with the featureGroup, and (2) the
