@@ -281,6 +281,7 @@ public class TrackMenuUtils {
             Feature f = t.getFeatureAtMousePosition(e);
             if (f != null) {
                 featurePopupMenu.addSeparator();
+                featurePopupMenu.add(getCopyDetailsItem(f, e.getX()));
                 featurePopupMenu.add(getCopySequenceItem(f));
 
             }
@@ -665,12 +666,12 @@ public class TrackMenuUtils {
         if (value == Integer.MIN_VALUE) {
             return;
         }
+        value = Math.max(0, value);
 
         for (Track track : selectedTracks) {
-            if (value > track.getMinimumHeight())
-                track.setHeight(value);
-            else
-                track.setHeight(track.getPreferredHeight());
+
+            track.setHeight(value);
+
         }
 
         refresh();
@@ -690,15 +691,15 @@ public class TrackMenuUtils {
         }
 
 
-        int origValue = featureTracks.iterator().next().featureVisibilityWindow();
-        final String parameter = "Track height";
-        int value = getIntValue("Feature visibility window", origValue);
+        int origValue = featureTracks.iterator().next().getVisibilityWindow();
+        int origValueKB = Math.max(1, origValue / 1000);
+        int value = getIntValue("Visibility window (kb)", origValueKB);
         if (value == Integer.MIN_VALUE) {
             return;
         }
 
         for (FeatureTrack track : featureTracks) {
-            track.setFeatureVisibilityWindow(value);
+            track.setVisibilityWindow((int) (value * 1000));
         }
 
         refresh();
@@ -725,6 +726,7 @@ public class TrackMenuUtils {
         refresh();
     }
 
+
     private static int getIntValue(String parameter, int value) {
 
         while (true) {
@@ -747,7 +749,6 @@ public class TrackMenuUtils {
         }
     }
 
-
     public static void changeTrackColor(final Collection<Track> selectedTracks) {
 
         if (selectedTracks.isEmpty()) {
@@ -795,8 +796,29 @@ public class TrackMenuUtils {
 
     }
 
+    public static JMenuItem getCopyDetailsItem(final Feature f, final int mouseX) {
+        JMenuItem item = new JMenuItem("Copy Details to Clipboard");
+        item.addActionListener(new ActionListener() {
+
+            public void actionPerformed(ActionEvent e) {
+                double location = ViewContext.getInstance().getChromosomePosition(mouseX);
+                String details = f.getValueString(location, null);
+                if (details != null) {
+                    details = details.replace("<br>",  System.getProperty("line.separator"));
+                    details += System.getProperty("line.separator") +
+                            f.getChr() + ":" + (f.getStart() + 1) + "-" + f.getEnd();
+                    StringSelection stringSelection = new StringSelection(details);
+                    Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
+                    clipboard.setContents(stringSelection, null);
+                }
+            }
+        });
+        return item;
+    }
+
+
     public static JMenuItem getCopySequenceItem(final Feature f) {
-        JMenuItem item = new JMenuItem("Copy Sequence");
+        JMenuItem item = new JMenuItem("Copy Sequence to Clipboard");
         item.addActionListener(new ActionListener() {
 
             public void actionPerformed(ActionEvent e) {
