@@ -80,6 +80,8 @@ public class IGVCommandBar extends javax.swing.JPanel {
     private javax.swing.JPanel zoomControl;
     private ItemListener genomeComboBoxItemListener = null;
     final private int DEFAULT_CHROMOSOME_DROPDOWN_WIDTH = 120;
+    private JideButton backButton;
+    private JideButton forwardButton;
 
     /**
      * Creates new form IGVCommandBar
@@ -778,6 +780,10 @@ public class IGVCommandBar extends javax.swing.JPanel {
             list.add(UIConstants.GENOME_LIST_SEPARATOR);
         }
 
+        if(list.isEmpty()) {
+            list.add(GenomeManager.getInstance().getDefaultGenomeListItem());
+        }
+
         return new DefaultComboBoxModel(list.toArray());
     }
 
@@ -855,12 +861,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
             cachedGenomeItemList = new LinkedHashSet<GenomeListItem>();
         }
 
-        /*if (clientItemList.isEmpty() && serverItemList.isEmpty() && cachedGenomeItemList.isEmpty()) {
-            JOptionPane.showMessageDialog(IGVMainFrame.getInstance(),
-                    "No genomes founds during configuration!");
-            throw new RuntimeException("No genomes founds during configuration!");
-        } */
-
+       
         this.userDefinedGenomeItemList = clientItemList;
         this.cachedGenomeItemList = cachedGenomeItemList;
         this.serverGenomeItemList = serverItemList;
@@ -972,6 +973,40 @@ public class IGVCommandBar extends javax.swing.JPanel {
 
         // toolPanel.setBorder(
         // new javax.swing.border.SoftBevelBorder(javax.swing.border.BevelBorder.RAISED));
+/*        backButton = new JideButton();
+        backButton.setIcon(
+                new javax.swing.ImageIcon(
+                        getClass().getResource("/toolbarButtonGraphics/navigation/Back24.gif")));    // NOI18N
+
+        backButton.setToolTipText("Back");
+        backButton.addActionListener(new java.awt.event.ActionListener() {
+
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                String locus = ViewContext.getInstance().history.back();
+                if (locus != null) {
+                    (new SearchCommand(ViewContext.getInstance(), locus, false)).execute();
+                }
+
+            }
+        });
+        toolPanel.add(backButton, JideBoxLayout.FIX);
+
+        forwardButton = new JideButton();
+        forwardButton.setIcon(
+                new javax.swing.ImageIcon(
+                        getClass().getResource("/toolbarButtonGraphics/navigation/Forward24.gif")));    // NOI18N
+        forwardButton.setToolTipText("Forward");
+        forwardButton.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                String locus = ViewContext.getInstance().history.forward();
+                if (locus != null) {
+                    (new SearchCommand(ViewContext.getInstance(), locus, false)).execute();
+                }
+
+            }
+        });
+        toolPanel.add(forwardButton, JideBoxLayout.FIX);
+*/
 
         homeButton = new com.jidesoft.swing.JideButton();
         homeButton.setAlignmentX(RIGHT_ALIGNMENT);
@@ -988,6 +1023,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
         });
         toolPanel.add(homeButton, JideBoxLayout.FIX);
 
+
         refreshButton = new com.jidesoft.swing.JideButton();
         refreshButton.setAlignmentX(RIGHT_ALIGNMENT);
         refreshButton.setIcon(
@@ -1060,6 +1096,7 @@ public class IGVCommandBar extends javax.swing.JPanel {
     private void homeButtonActionPerformed(java.awt.event.ActionEvent evt) {
         String chr = getViewContext().getHomeChr();
         getViewContext().setChromosomeName(chr);
+        getViewContext().history.push(chr);
         chromosomeComboBox.setSelectedItem(chr);
         updateCurrentCoordinates();
         owner.chromosomeChangeEvent();
@@ -1074,8 +1111,9 @@ public class IGVCommandBar extends javax.swing.JPanel {
     private void chromosomeComboBoxActionPerformed(java.awt.event.ActionEvent evt) {
         javax.swing.JComboBox combobox = ((javax.swing.JComboBox) evt.getSource());
         String chromosomeName = (String) combobox.getSelectedItem();
-        if (chromosomeName != null) {
+        if (chromosomeName != null  && !chromosomeName.equals(getViewContext().getChrName())) {
             getViewContext().setChromosomeName(chromosomeName);
+            getViewContext().recordHistory();
             updateCurrentCoordinates();
             owner.chromosomeChangeEvent();
             owner.repaint();
