@@ -28,9 +28,9 @@ package org.broad.igv.ui.panel;
 //~--- non-JDK imports --------------------------------------------------------
 
 import org.apache.log4j.Logger;
+import org.broad.igv.PreferenceManager;
 import org.broad.igv.exceptions.DataLoadException;
 import org.broad.igv.renderer.DataRange;
-import org.broad.igv.renderer.XYPlotRenderer;
 import org.broad.igv.session.ViewContext;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.track.Track;
@@ -39,6 +39,7 @@ import org.broad.igv.ui.*;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.ui.util.Packable;
 import org.broad.igv.ui.util.UIUtilities;
+import org.broad.igv.util.ResourceLocator;
 
 import javax.swing.*;
 import javax.swing.event.MouseInputAdapter;
@@ -51,9 +52,7 @@ import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
 import java.io.File;
 import java.text.DecimalFormat;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Iterator;
+import java.util.*;
 import java.util.List;
 
 /**
@@ -198,6 +197,7 @@ public class DataPanel extends TrackPanelComponent {
                 }
             }
             if (!hasTracks) {
+                removeMousableRegions();
                 return;
             }
 
@@ -243,8 +243,8 @@ public class DataPanel extends TrackPanelComponent {
             }
 
 
-            if (IGVMainFrame.getInstance().isShowRegionsOfInterestBarsOn() || (currentTool instanceof RegionOfInterestTool)) {
-                drawRegionsOfInterest(g, getHeight(), getViewContext());
+            if (IGVMainFrame.getInstance().isShowRegionsOfInterestBarsOn()) {
+                drawAllRegions(g);
             }
 
         } finally {
@@ -259,11 +259,8 @@ public class DataPanel extends TrackPanelComponent {
      * Method description
      *
      * @param g
-     * @param height
-     * @param viewContext
      */
-    public void drawRegionsOfInterest(final Graphics g, int height,
-                                      ViewContext viewContext) {
+    public void drawAllRegions(final Graphics g) {
 
         Collection<RegionOfInterest> regions =
                 IGVMainFrame.getInstance().getSession().getRegionsOfInterest(getViewContext().getChrName());
@@ -272,29 +269,14 @@ public class DataPanel extends TrackPanelComponent {
             return;
         }
 
+        boolean drawBars = PreferenceManager.getInstance().isShowRegionBars();
         Graphics2D graphics2D = (Graphics2D) g.create();
         try {
 
             for (RegionOfInterest regionOfInterest : regions) {
-
-                Integer regionStart = regionOfInterest.getStart();
-                if (regionStart == null) {
-
-                    // skip - null starts are bad regions of interest
-                    continue;
+                if (drawBars || regionOfInterest == IGVMainFrame.getInstance().getSelectedRegion()) {
+                    drawRegion(graphics2D, regionOfInterest);
                 }
-
-                Integer regionEnd = regionOfInterest.getEnd();
-                if (regionEnd == null) {
-                    regionEnd = regionStart;
-                }
-                int start = viewContext.getPixelPosition(regionStart);
-                int end = viewContext.getPixelPosition(regionEnd);
-
-                // Set foreground color of boundaries
-                graphics2D.setColor(regionOfInterest.getForegroundColor());
-                graphics2D.drawLine(start, 0, start, height);
-                graphics2D.drawLine(end, 0, end, height);
             }
         } finally {
             if (graphics2D != null) {
@@ -303,6 +285,28 @@ public class DataPanel extends TrackPanelComponent {
         }
     }
 
+    private boolean drawRegion(Graphics2D graphics2D, RegionOfInterest regionOfInterest) {
+        Integer regionStart = regionOfInterest.getStart();
+        if (regionStart == null) {
+            return true;
+        }
+
+        Integer regionEnd = regionOfInterest.getEnd();
+        if (regionEnd == null) {
+            regionEnd = regionStart;
+        }
+        ViewContext viewContext = getViewContext();
+        int start = viewContext.getPixelPosition(regionStart);
+        int end = viewContext.getPixelPosition(regionEnd);
+
+        // Set foreground color of boundaries
+        int height = getHeight();
+        graphics2D.setColor(regionOfInterest.getForegroundColor());
+        graphics2D.drawLine(start, 0, start, height);
+        graphics2D.drawLine(end, 0, end, height);
+        return false;
+    }
+
     protected String generateTileKey(final String chr, int t,
                                      final int zoomLevel) {
 
@@ -586,6 +590,7 @@ public class DataPanel extends TrackPanelComponent {
                     WaitCursorManager.CursorToken token = WaitCursorManager.showWaitCursor();
                     try {
                         getViewContext().shiftOriginPixels(-getWidth());
+                        getViewContext().recordHistory();
                     } finally {
                         WaitCursorManager.removeWaitCursor(token);
                     }
@@ -595,6 +600,7 @@ public class DataPanel extends TrackPanelComponent {
                     WaitCursorManager.CursorToken token = WaitCursorManager.showWaitCursor();
                     try {
                         getViewContext().shiftOriginPixels(getWidth());
+                        getViewContext().recordHistory();
                     } finally {
                         WaitCursorManager.removeWaitCursor(token);
                     }
@@ -789,6 +795,7 @@ public class DataPanel extends TrackPanelComponent {
 
         @Override
         public void mouseExited(MouseEvent e) {
+            IGVMainFrame.getInstance().setSelectedRegion(null);
         }
 
         /**
@@ -868,17 +875,25 @@ public class DataPanel extends TrackPanelComponent {
 
             Transferable transferable = event.getTransferable();
 
+            DataFlavor[] flavors = transferable.getTransferDataFlavors();
+
             MessageCollection messages = new MessageCollection();
             try {
-                List<File> files = (List<File>) transferable.getTransferData(DataFlavor.javaFileListFlavor);
 
-                for (File file : files) {
-                    try {
+                String obj = transferable.getTransferData(DataFlavor.stringFlavor).toString();
+                if (obj.startsWith("http:")) {
+                      IGVMainFrame.getInstance().loadTracks(Arrays.asList(new ResourceLocator(obj)));
+                } else {
+                    List<File> files = (List<File>) transferable.getTransferData(DataFlavor.javaFileListFlavor);
 
-                        IGVMainFrame.getInstance().getTrackManager().load(file, panel);
-                    }
-                    catch (DataLoadException de) {
-                        messages.append(de.getMessage());
+                    for (File file : files) {
+                        try {
+
+                            IGVMainFrame.getInstance().getTrackManager().load(file, panel);
+                        }
+                        catch (DataLoadException de) {
+                            messages.append(de.getMessage());
+                        }
                     }
                 }
 
