@@ -25,7 +25,6 @@
  */
 package org.broad.igv.ui.panel;
 
-//~--- non-JDK imports --------------------------------------------------------
 
 import org.apache.log4j.Logger;
 import org.broad.igv.track.Track;
@@ -58,9 +57,27 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
     private static Logger log = Logger.getLogger(TrackNamePanel.class);
 
 
+    // TODO -- this use of a static is really bad,  bugs and memory leaks waiting to happen.  Redesign this.
     static List<DropListener> dropListeners = new ArrayList();
 
 
+    static void addGhostDropListener(DropListener listener) {
+        if (listener != null) {
+            dropListeners.add(listener);
+        }
+    }
+
+    public static void removeDropListenerFor(TrackNamePanel panel) {
+        List<DropListener> removeThese = new ArrayList();
+        for (DropListener dl : dropListeners) {
+            if (dl.panel == panel) {
+                removeThese.add(dl);
+            }
+        }
+        dropListeners.removeAll(removeThese);
+    }
+
+
     List<GroupExtent> groupExtents = new ArrayList();
 
     BufferedImage dndImage = null;
@@ -69,6 +86,8 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
 
     boolean showGroupNames = true;
 
+    boolean showSampleNamesWhenGrouped = false;
+
 
     public TrackNamePanel(TrackPanel trackPanel) {
         super(trackPanel);
@@ -88,7 +107,7 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
 
     @Override
     public void paintComponent(Graphics g) {
-        
+
         super.paintComponent(g);
 
         removeMousableRegions();
@@ -176,8 +195,10 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
                     Rectangle region = new Rectangle(regionX, regionY, width, height);
                     addMousableRegion(new MouseableRegion(region, track));
 
-                    Rectangle rect = new Rectangle(regionX, regionY, width, height);
-                    track.renderName(graphics2D,rect, visibleRect);                    
+                    if (!isGrouped() || showSampleNamesWhenGrouped) {
+                        Rectangle rect = new Rectangle(regionX, regionY, width, height);
+                        track.renderName(graphics2D, rect, visibleRect);
+                    }
 
                 }
                 regionY += trackHeight;
@@ -227,6 +248,17 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
                 }
             });
             menu.add(item);
+
+            final JMenuItem item2 = new JCheckBoxMenuItem("Show sample names");
+            item2.setSelected(showSampleNamesWhenGrouped);
+            item2.addActionListener(new ActionListener() {
+                public void actionPerformed(ActionEvent e) {
+                    showSampleNamesWhenGrouped = item2.isSelected();
+                    clearTrackSelections();
+                    repaint();
+                }
+            });
+            menu.add(item2);
             menu.addSeparator();
         }
 
@@ -264,12 +296,6 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
         return "";
     }
 
-    static void addGhostDropListener(DropListener listener) {
-        if (listener != null) {
-            dropListeners.add(listener);
-        }
-    }
-
     /**
      * Listener for scroll pane events
      *
@@ -336,6 +362,8 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
                 log.debug("Enter mousePressed");
             }
 
+            dragStart = e.getPoint();
+
             requestFocus();
             grabFocus();
 
@@ -447,7 +475,11 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
                 return;
             }
             if (!isDragging) {
-                dragStart = e.getPoint();
+
+                if(e.getPoint().distance(dragStart) < 5) {
+                    return;
+                }
+
                 dragStart.x = getWidth() / 2;
                 IGVMainFrame.getInstance().startDnD();
 
@@ -512,7 +544,7 @@ public class TrackNamePanel extends TrackPanelComponent implements AdjustmentLis
 
         public DropListener(TrackNamePanel target) {
             super(target);
-
+            this.panel = target;
         }
 
         public void ghostDropped(GhostDropEvent e) {
