@@ -33,6 +33,7 @@ import org.broad.igv.ui.util.MessageUtils;
 
 import java.awt.*;
 import java.io.*;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.List;
@@ -49,7 +50,8 @@ public class ParsingUtils {
             throws FileNotFoundException, IOException {
         BufferedReader reader = null;
 
-        if (pathOrUrl.startsWith("http:") || pathOrUrl.startsWith("file:")) {
+        if (pathOrUrl.startsWith("http:") || pathOrUrl.startsWith("https:") ||
+                pathOrUrl.startsWith("file:")) {
             URL url = new URL(pathOrUrl);
             reader = new BufferedReader(new InputStreamReader(IGVHttpUtils.openConnectionStream(url)));
         } else {
@@ -73,7 +75,8 @@ public class ParsingUtils {
         AsciiLineReader reader = null;
         try {
             long fileLength = 0;
-            if (filename.startsWith("http")) {
+            //TODO -- ftp
+            if (filename.startsWith("http:") || filename.startsWith("https:")) {
                 URL url = new URL(filename);
                 fileLength = Long.parseLong(IGVHttpUtils.getHeaderField(url, "Content-length"));
             } else {
@@ -155,7 +158,8 @@ public class ParsingUtils {
         } else {
 
             InputStream inputStream = null;
-            if (locator.getPath().startsWith("http:") || locator.getPath().startsWith("file:")) {
+            if (locator.getPath().startsWith("http:") || locator.getPath().startsWith("https:") ||
+                    locator.getPath().startsWith("ftp:") || locator.getPath().startsWith("file:")) {
                 URL url = new URL(locator.getPath());
                 inputStream = IGVHttpUtils.openConnectionStream(url);
             } else {
@@ -490,6 +494,7 @@ public class ParsingUtils {
 
                         }
                     } else if(key.equals("maxfeaturewindow") || key.equals("featurevisibilitywindow")) {
+                        // These options are deprecated.  Use visibilityWindow
                         try {
                             int windowSize = Integer.parseInt(value);
                             trackProperties.setFeatureVisibilityWindow(windowSize);
@@ -497,7 +502,16 @@ public class ParsingUtils {
                             log.error("featureVisibilityWindow must be numeric: " + nextLine);
                         }
 
-                    } else if(key.equals("scaletype")) {
+                    } else if(key.equals("visibilitywindow")) {
+                        try {
+                            int windowSize = Integer.parseInt(value) * 1000;
+                            trackProperties.setFeatureVisibilityWindow(windowSize);
+                        } catch (NumberFormatException e) {
+                            log.error("featureVisibilityWindow must be an integer: " + nextLine);
+                        }
+
+                    }
+                    else if(key.equals("scaletype")) {
                         if(value.equals("log")) {
                             trackProperties.setLogScale(true);
                         }
@@ -519,4 +533,15 @@ public class ParsingUtils {
         return foundProperties;
 
     }
+
+    public static  boolean pathExists(String covPath)  {
+        try {
+            return (new File(covPath)).exists() ||
+                    ((covPath.startsWith("http:") || covPath.startsWith("https:")) &&
+                            IGVHttpUtils.resourceAvailable(new URL(covPath)));
+        } catch (MalformedURLException e) {
+            // todo -- log
+            return false;
+        }
+    }
 }
