@@ -1,18 +1,18 @@
 package org.broad.tribble.index;
 
-import net.sf.samtools.SAMSequenceDictionary;
 import org.broad.tribble.util.LittleEndianInputStream;
+import org.broad.tribble.util.LittleEndianOutputStream;
 
 import java.io.IOException;
+import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Set;
 
 /**
- * Interface for all index implementations.  
+ * Interface for all index implementations.
  */
 public interface Index {
     /**
-     * 
+     *
      * @param chr the chromosome
      * @param start the start position
      * @param end the end position
@@ -20,24 +20,29 @@ public interface Index {
      */
     List<Block> getBlocks(String chr, int start, int end);
 
-    /**
-     * returns the sequence dictionary, if available, for this index file
-     * @return a sequence dictionary, or NULL if not available.
-     */
-    SAMSequenceDictionary getSequenceDictionary();
-
-    /**
-     * sets the sequence dictionary for this index file (prior to writing the file)
-     */
-    void setSequenceDictionary(SAMSequenceDictionary dictionary);
-
     /**
      * does this index represent an up-to-date version
      * @return true if the index is up to date, false otherwise
      */
     public boolean isCurrentVersion();
 
-    Set<String> getSequenceNames();
+    /**
+     * get a list of the sequence names we've seen during indexing, in order
+     * @return a LinkedHashSet, which guarantees the ordering
+     */
+    LinkedHashSet<String> getSequenceNames();
 
+    /**
+     * read in the index
+     * @param stream an input stream to read from
+     * @throws IOException if we have problems reading the index from the stream
+     */
     public void read(LittleEndianInputStream stream)  throws IOException;
+
+    /**
+     * all indexes are writable to disk
+     * @param stream the stream to write the index to
+     * @throws IOException if the index is unable to write to the specified location
+     */
+    public void write(LittleEndianOutputStream stream) throws IOException;
 }
